@@ -9,15 +9,19 @@ class AnalysisController < ApplicationController
   def index
     if path = params[:path]
       analysis = Analysis.create_from_path(path)
-      session[:analysis] = analysis
-      ary = (session[:variables_list] ||= Array.new)
-      analysis.variables.each do |var|
-        pa = var.path.sub(/\/cut\([^)]+\)\Z/,"")
-        ary.push(pa) unless ary.include?(pa)
+      if analysis.draw_method
+        session[:analysis] = analysis
+        ary = (session[:variables_list] ||= Array.new)
+        analysis.variables.each do |var|
+          pa = var.path.sub(/\/cut\([^)]+\)\Z/,"")
+          ary.push(pa) unless ary.include?(pa)
+        end
+        #      redirect_to
+        execute_draw(analysis, false)
+        return
+      else
+        @analysis = analysis
       end
-#      redirect_to
-      execute_draw(analysis, false)
-      return
     else
       @analysis = (session[:analysis] ||= Analysis.new)
     end
@@ -430,27 +434,24 @@ EOF
       render :nothing => true
       return
     end
-=begin
     lower_id = params[:lower].to_i
     upper_id = params[:upper].to_i
     if (diagrams = session[:diagrams])
-      session_id = session.session_id
-      lower = DiagramCache.find_for_session(diagrams[lower_id],session_id)
-      upper = DiagramCache.find_for_session(diagrams[upper_id],session_id)
-      if lower && upper
-        a = YAML.load(lower.vizshot)
-        b = YAML.load(upper.vizshot)
-        viz = a.add(b)
-#        viz = YAML.load(lower.vizshot).add(YAML.load(upper.vizshot))
-        res = vizs_to_diagram([viz], true, session[:analysis].draw_share, true)
-        show_diagram(res, true, false, true)
-        return
-      end
-    end
-    render :nothing => true
-=end
-    render :update do |page|
-      page.replace_html :messages, "Sorry, pile-up is disabled in this version."
+      newpath = "/[" + diagrams[lower_id] + "," +diagrams[upper_id] + "]/overlay()"
+      id = diagrams.length
+      diagrams.push(newpath)
+      render(:update){|page|
+        page.replace_html :messages, ""
+
+        @diagram = [id, newpath]
+        page.insert_html :top, :diagrams, render(:partial => "diagram")
+
+        # "Create Knowledge from Analysis" button is disabled if login menu is disabled.
+        page << "drawKnowledgeFromAnalysisButton();" unless GFDNAVI_DISABLE_USER && session[:user].nil?
+
+        @history = session[:history]
+        page.replace_html :history, render(:partial => "history")
+      }
     end
     return
   end
@@ -565,7 +566,13 @@ EOF
     keep = anim || analysis.draw_keep
     dm = analysis.draw_method
     dm_opts = analysis.get_draw_options
-    vars = get_variables(analysis, :cut => true)
+    vorder = dm_opts.delete("variables_order")
+    if vorder.is_a?(Hash)
+      tmpvorder = []
+      vorder.each{|key, val| tmpvorder[key.to_i] = val}
+      vorder = tmpvorder
+    end
+    vars = get_variables(analysis, :order => vorder, :cut => true)
     plots = vars.plot(dm, dm_opts)
     if keep
       dgs = (session[:diagrams] ||= Array.new)
@@ -575,10 +582,11 @@ EOF
     id0 = dgs.length
     new_dgs = Array.new
     plots.each{|plot|
-      plot.to_png # for execute
       path = plot.path
       dgs.push path
       new_dgs.push path
+      # make the actual image file(s) and the cache on the database
+      NumRu::GfdnaviData::Local.parse_path(path,analysis.user).to_png
     }
     if request.xhr?
       @analysis = session[:analysis]
