@@ -196,7 +196,7 @@ class FunctionController < ApplicationController
     begin
       ERB.new(html).run
       return true
-    rescue SyntaxError
+    rescue #SyntaxError
       flash[:notice] = "html is invalid"
       return false
     end
