@@ -1,11 +1,11 @@
-# -*- coding: sjis -*-
+# -*- coding: japanese-cp932 -*-
 require "numru/vizshot_gfdnavi"
 require "virtual_data"
 require "pp"
 
 class KnowledgeController < ApplicationController
   layout "gfdnavi", :except => [:list_without_layout, :show_without_layout, :category_search, :comment_written]
-  before_filter :login_required, :except => [:index, :list, :list_without_layout, :show, :show_without_layout, :appear_comment_input_form, :fig2analysis, :category_search]
+  before_filter :login_required, :except => [:index, :list, :list_without_layout, :show, :show_without_layout, :appear_comment_input_form, :fig2analysis, :fig2analysis2, :category_search]
   verify :method => :post, :only => [ :destroy_document, :create, :update ], :redirect_to => { :action => :list }
 
   def index
@@ -107,7 +107,7 @@ class KnowledgeController < ApplicationController
     render :action => 'list'
   end
 
-  # mhLg̉{
+  # mhLg{
   def show
     begin
       @user = (login=session[:user]) && User.find_by_login(login)
@@ -131,6 +131,22 @@ class KnowledgeController < ApplicationController
     render :action => 'show'
   end
 
+  # mhLg쐬邽߂̃XNvg\
+  def script
+    begin
+      user = (login=session[:user]) && User.find_by_login(login)
+      knowledge = Knowledge.find(:first, :conditions => ["path=?", params[:path]], :user => user)
+      @knowledge_script = knowledge.get_script(user)
+    rescue => exception
+      # ́̕Aknowledge.save ̓ł
+      # ۑO before_save \bhsĂB
+      # オĂOߑB
+      flash[:notice] = exception
+      redirect_to :action => 'list'
+    end
+  end
+
+
   # list.rhtml -> new.rhtml (Click "New Knowledge" button.)
   def new
     @type = "new"
@@ -294,7 +310,9 @@ class KnowledgeController < ApplicationController
         if params[:groups]
           groups = params[:groups].values # Hash to Array
         else
-          raise "Check at least 1 group to visible!\n"
+          flash[:notice] = "Check at least 1 group to visible!"
+          redirect_to :action => "edit", :from_list => "from_list", :path => knowledge.path
+          return
         end
       end
 
@@ -346,90 +364,67 @@ class KnowledgeController < ApplicationController
       end
     end
 
-    # path̒g`FbNBpathǂ`FbNB
-    if @type=="temporary_save"
-      # read_knowledge_hash \bhōēx`FbN̂
-      if path =~ /\/\s*$/ || path =~ /\/\s*\//
-        path_error = "Path Error! You input #{path}. " + "Directory that doesn't have name is forbidden."
+    # ҏW̏㏑ۑꎞIȕۑ̏ꍇApX̏dȂǂ̓`FbNȂ悤ɂB
+    # (modelbefore_saveŐ)
+    if (@type=="edit" && @commit=="Save") || (@type == "temporary_save") || (@type=="comment" && @commit=="Add a Comment on this document.")
+      knowledge.ignore_check_path = true
+    end
+
+    # === knowledge_figures e[u
+    #     ܂}𐳂ԂɃ\[gBsortArrayԂ̂ŁAHashɖ߂ĂB
+    kf_hash_ary = []
+    if params["knowledge_figure"]
+      sorted_kf = params["knowledge_figure"].sort {|a, b| a[0].to_i <=> b[0].to_i}
+      sorted_kf.each {|key, value| kf_hash_ary.push value } # Hash  Array ɂ
+      kf_hash_ary.delete_if {|kf_hash| kf_hash["figure_path"] == ""} # path ͍̂폜
+    end
+
+    notfound_error = ""
+    # kf_hash Ɋ҂Ă̂́Aimage_path  caption ̂
+    kf_hash_ary.each_with_index do |kf_hash, index|
+      # 摜pathHashɊi[B
+      # path = ܂ۑĂȂ@ꍇ͂܂摜ۑ
+      #
+      # new_from_analysis ȊO  find  nil ɂȂƂ
+      # ݂Ȃ摜̃pX\ƂB
+
+      if image = Image.find(:first, :conditions => ["path=?", kf_hash["figure_path"] + ".png"], :user => user)
+        # ̉摜̏ꍇ͂path𗘗p
+        image_path = image.path
+      else
+        # VK̉摜Ƃ݂Ȃ(kf_hash["figure_path"]ɂ org_path Ă)
+        if @type=="new_from_analysis"
+          gd = NumRu::GfdnaviData.open(kf_hash["figure_path"], user)
+          image_path = knowledge.image_save(path[0..-7], index, kf_hash["name"], gd, user)
+        else
+          # new_from_analysisȊȌꍇ͐VK̉摜͓ȂBpXԈĂB
+          notfound_error += "Image not found."
+        end
       end
-      knowledge.ignore_check_path = true
-    elsif @type=="edit" && @commit=="Save"
-      # read_knowledge_hash \bhōēx`FbN̂
-      knowledge.ignore_check_path = true
-    else
-      path_error = knowledge.check_path(path)
-      if Knowledge.find(:first, :conditions => ["path=?", path], :user => :all)
-        same_path_error = "Failure to save!!! Inputted path \"#{path}\" already exists.\n"
+
+      # image_path  nil ȂpX(kf_hash["figure_path"])ԈĂƂăG[
+      unless image_path
+        notfound_error += "#{kf_hash['figure_path']}.png not found.\n"
+      else
+        kf_hash["image_path"] = image_path
+        kf_hash["caption"] = kf_hash["figure_caption"]
+        kf_hash.delete("name")
+        kf_hash.delete("figure_number")
+        kf_hash.delete("diagram_id")
+        kf_hash.delete("figure_caption")
+        kf_hash.delete("figure_path")
       end
     end
 
-
-    # 炩̃G[ɈĂ炻óB
-    # SẴG[ĂۑɈڍsB
-    if same_path_error
-      flash[:notice] = same_path_error
-      redirect_to :action => 'list'
-    elsif path_error
-      flash[:notice] = path_error
-      redirect_to :action => 'list'
-    elsif category_error
-      flash[:notice] = category_error
+    # 摜Ȃꍇ̓G[ɂ
+    unless notfound_error == ""
+      flash[:notice] = notfound_error
       redirect_to :action => 'list'
     else
-      # === knowledge_figures e[u
-      #     ܂}𐳂ԂɃ\[gBsortArrayԂ̂ŁAHashɖ߂ĂB
-      kf_hash_ary = []
-      if params["knowledge_figure"]
-        sorted_kf = params["knowledge_figure"].sort {|a, b| a[0].to_i <=> b[0].to_i}
-        sorted_kf.each {|key, value| kf_hash_ary.push value } # Hash  Array ɂ
-        kf_hash_ary.delete_if {|kf_hash| kf_hash["figure_path"] == ""} # path ͍̂폜
-      end
-
-      notfound_error = ""
-      # kf_hash Ɋ҂Ă̂́Aimage_path  caption ̂
-      kf_hash_ary.each_with_index do |kf_hash, index|
-        # 摜pathHashɊi[B
-        # path = ܂ۑĂȂ@ꍇ͂܂摜ۑ
-        #
-        # new_from_analysis ȊO  find  nil ɂȂƂ
-        # ݂Ȃ摜̃pX\ƂB
-
-        if image = Image.find(:first, :conditions => ["path=?", kf_hash["figure_path"] + ".png"], :user => user)
-          # ̉摜̏ꍇ͂path𗘗p
-          image_path = image.path
-        else
-          # VK̉摜Ƃ݂Ȃ(kf_hash["figure_path"]ɂ org_path Ă)
-          if @type=="new_from_analysis"
-            gd = NumRu::GfdnaviData.open(kf_hash["figure_path"])
-            image_path = knowledge.image_save(path[0..-7], index, kf_hash["name"], gd, user)
-          else
-            # new_from_analysisȊȌꍇ͐VK̉摜͓ȂBpXԈĂB
-            notfound_error += "Image not found."
-          end
-        end
-
-        # image_path  nil ȂpX(kf_hash["figure_path"])ԈĂƂăG[
-        unless image_path
-          notfound_error += "#{kf_hash['figure_path']}.png not found.\n"
-        else
-          kf_hash["image_path"] = image_path
-          kf_hash["caption"] = kf_hash["figure_caption"]
-          kf_hash.delete("name")
-          kf_hash.delete("figure_number")
-          kf_hash.delete("diagram_id")
-          kf_hash.delete("figure_caption")
-          kf_hash.delete("figure_path")
-        end
-      end
-
-      # 摜Ȃꍇ̓G[ɂ
-      unless notfound_error == ""
-        flash[:notice] = notfound_error
-        redirect_to :action => 'list'
-      else
-        comment_hash = nil
-        refer_hash_ary = Array.new
-        # === ۑ    
+      comment_hash = nil
+      refer_hash_ary = Array.new
+      # === ۑ
+      begin
         Knowledge.transaction do
           knowledge.delete_node_relations if @type=="edit" && @commit=="Save" # @type == "edit_save"
           knowledge.read_knowledge_hash(path, k_hash, size=nil)
@@ -463,33 +458,12 @@ class KnowledgeController < ApplicationController
             render :partial => "backup"
           end
         end
-=begin
-        case @type
-        when "temporary_save"
-          knowledge.id = params[:original_id]
-          knowledge.create_backup(@type, kf_hash_ary, groups)
-          # Ō@knowledge, @user̒gĂ(renderɕKv)
-          @knowledge = knowledge
-          @user = user
-          flash[:notice] = "Temporary save.\n"
-          render :partial => "backup"
-        when "edit_save"
-          knowledge.save! # Knowledge.save
-          knowledge_copy.create_backup(@type, kf_hash_ary, groups)
-          @knowledge = knowledge
-          flash[:notice] = "A knowledge document is successfully saved."
-          redirect_to :action => 'show', :path => path, :from => 'update'
-        else
-          knowledge.save! # Knowledge.save
-          @knowledge = knowledge        
-          if @type == "comment"
-            redirect_to :action => 'comment_written', :path => parent_knowledge.path
-          else
-            flash[:notice] = "A knowledge document is successfully saved."
-            redirect_to :action => 'show', :path => path, :from => 'update'
-          end
-        end
-=end
+      rescue => exception
+        # ́̕Aknowledge.save ̓ł
+        # ۑO before_save \bhsĂB
+        # オĂOߑB
+        flash[:notice] = exception
+        redirect_to :action => 'list'       
       end
     end
   end
@@ -896,7 +870,7 @@ class KnowledgeController < ApplicationController
   # /view/knowledge/_layout_figure.rhtml Ŏgp
   def fig2analysis
     user = (login=session[:user]) && User.find_by_login(login)
-    analysis = Analysis.create_from_path(params[:org_path])
+    analysis = Analysis.create_from_path(params[:org_path],user)
     session[:analysis] = analysis
 
     # ϐꗗɕϐ邽߂ɕKv
@@ -908,6 +882,12 @@ class KnowledgeController < ApplicationController
     redirect_to :controller => "analysis", :action => "index"
   end
 
+  def fig2analysis2
+    session[:diagrams] ||= []
+    session[:diagrams].unshift(params[:org_path]) # add at the top
+    redirect_to :controller => "analysis2", :action => "index"
+  end
+
 =begin
   private
   def make_directories(obj, user, groups, other_mode)
