@@ -1,3 +1,4 @@
+# -*- coding: cp932 -*-
 class UserController < ApplicationController
   # for OpenID
   require 'ostruct'
@@ -33,7 +34,7 @@ class UserController < ApplicationController
         redirect_back_or_default :action => "index"
       else
         flash.now[:notice]  = "Login unsuccessful"
-        @login = params[:user_login]
+        @login = params[:user][:login]
       end
     end
   end
@@ -178,8 +179,8 @@ class UserController < ApplicationController
       flash[:notice] = "authorization of #{user.login} was succeeded"
       @uri = uri_prefix
       if GFDNAVI_ENABLE_EMAIL
-        UserMailer.deliver_signup_accepted(new_user, url_prefix)
-        UserMailer.deliver_authorization_inform(new_user, url_prefix, suser, "accept")
+        UserMailer.deliver_signup_accepted(new_user, uri_prefix)
+        UserMailer.deliver_authorization_inform(new_user, uri_prefix, suser, "accept")
       end
     else
       flash[:notice] = "authorization of #{user.login} was failed"
@@ -188,15 +189,15 @@ class UserController < ApplicationController
   end
 
   def reject_signup
-    suser = (login=session[:user]) && User.find_by_login(user)
+    suser = (user=session[:user]) && User.find_by_login(user)
     unless User.super_user?(suser)
       redirect_to :action => "index"
     end
     user = SignUpUser.find(params['id'])
-    @uri = url_prefix
+    @uri = uri_prefix
     if GFDNAVI_ENABLE_EMAIL
-      UserMailer.deliver_signup_rejected(user, url_prefix)
-      UserMailer.deliver_authorization_inform(user, url_prefix, suser, "reject")
+      UserMailer.deliver_signup_rejected(user, uri_prefix)
+      UserMailer.deliver_authorization_inform(user, uri_prefix, suser, "reject")
     end
     user.destroy
     redirect_to :action => "index"
