@@ -30,9 +30,9 @@ class Function < NodeEntityAbstract
     function_arguments.each{|fa|
       h2 = Hash.new
       h2[:description] = fa.description
-      h2[:value_type] = fa.value_type.name
+      h2[:value_type] = (vt=fa.value_type) && vt.name
       h2[:default] = fa.default
-      h2[:position] = fs.position
+      h2[:position] = fa.position
       ary.push h2
     }
     h[:arguments] = ary
