@@ -142,7 +142,7 @@ class Group < ActiveRecord::Base
     File.open(fname,"w"){|file| file.print yml.to_yaml}
   end
 
-  def save_file_desroy
+  def save_file_destroy
     fname = File.join(RAILS_ROOT,"db","group_#{RAILS_ENV}.yml")
     if File.exist?(fname)
       yml = YAML.load(File.read(fname))
