@@ -2,7 +2,9 @@ class Image < NodeEntityAbstract
 
   def png
     if /\.png\z/ =~ name
-      return File.read(fname)
+      image = File.read(fname)
+      image = image.force_encoding('ASCII-8BIT') if image.respond_to?(:force_encoding) # RUBY 1.9
+      return image
     else
       return nil
     end
