@@ -201,6 +201,9 @@ class Node < ActiveRecord::Base
     self.wgroups = Group.bit_mask_for(*groups)
   end
 
+  def visibility
+    Group.find_by_bit_flag(self.rgroups).collect{|g| g.name}
+  end
 
   alias _children children
   def children(reload=false, hash={})
