@@ -1,3 +1,4 @@
+# -*- coding: cp932 -*-
 class InitialScheme < ActiveRecord::Migration
 
   def self.up
@@ -182,8 +183,11 @@ class InitialScheme < ActiveRecord::Migration
       t.column "name", :string, :null => false
       t.column "value_type_id", :integer, :null => false
       t.column "default", :string
+      t.column "min", :string
+      t.column "max", :string
       t.column "optional", :boolean, :default => false, :null => false
       t.column "parser", :string
+      t.column "description", :text
     end
 
     create_table "users", :force => true do |t|
