@@ -1,5 +1,5 @@
 #!/usr/bin/env ruby
-# -*- coding: sjis -*-
+# -*- coding: japanese-cp932 -*-
 
 RAILS_ENV = 'production' if ARGV.delete('-p') or ARGV.delete('--production')
 
@@ -233,26 +233,36 @@ begin
     end
   end
 
-  print "\nregistering node relations\n"
-  # name, reference, referenced_by
-  if @references
-    @references.each{|ref|
+rescue
+  print "\n"
+  raise $!
+end
+
+
+# node_relationse[uɊւĂ
+print "\nregistering node relations\n"
+# name, reference, referenced_by
+if @references
+  @references.each{|ref|
+    begin
       nr = NodeRelation.new
       nr.name = ref[0]
       nr.reference = Node.find(:first,:conditions=>["path=?",ref[1]], :user=>:all)
       nr.referenced_by = Node.find(:first,:conditions=>["path=?",ref[2]], :user=>:all)
       nr.save!
-    }
-  end
+    rescue
+      print "Warning: a node relation failed to save.\n"
+      print "#{ref[1]} is missing.\n" unless nr.reference
+      print "#{ref[2]} is missing.\n" unless nr.referenced_by
+      print "#{$!}\n"
+    end
+  }
+end
 
 #  # ut@Co^łȂ̈ꗗvo͂
 #  ToDo.each do |node, proc|
 #    print "file \"#{node}\" not found, so is not registered.\n"
 #  end
 
-rescue
-  print "\n"
-  raise $!
-end
 
 print "\n"
