@@ -1,19 +1,25 @@
 #!/usr/bin/env ruby
 require "fileutils"
 require "yaml"
-
+require 'rbconfig'
 RDBMS = %w(MySQL SQLite3)
 @src_top = File.dirname( File.expand_path(__FILE__) )
 
+$ruby_bin = File::join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name'])
+$ruby_bin << RbConfig::CONFIG['EXEEXT']
+puts "running " << $ruby_bin
+
 # SET RAILS-COMMAND
 # RAILS IS NOW BUNDLED FOR THE RELEASE VERSION
-$rails_bin = "ruby " + File.join(Dir.pwd,"vendor","rails","railties","bin","rails") 
-puts "checking bundled rails..."
-has_rails = system($rails_bin + " -v")
+$rails_path = File.join(Dir.pwd, "vendor", "rails", "railties", "bin", "rails") 
+$rails_bin = $ruby_bin + " " + $rails_path
+print "checking bundled rails... "
+has_rails = File.exist?($rails_path) && system($rails_bin + " -v")
+print "no\n" unless has_rails
 
 if RUBY_PLATFORM =~ /mswin|mingw|bccwin/
   # FOR WINDOWS
-  $rails_bin = "ruby " + File.join(ENV['RBPATH'],"rails") unless has_rails
+  $rails_bin = $ruby_bin + " " + File.join(ENV['RBPATH'],"rails") unless has_rails
   $dev_null = "null"
 else
   # FOR UNIX-LIKE SYSTEMS
@@ -21,8 +27,11 @@ else
   $dev_null = "/dev/null"
 end
 unless has_rails
-  puts "checking system rails..."
-  raise "rails command was not found" unless has_rails = system($rails_bin + " -v")
+  print "checking system rails... "
+  unless has_rails = system($rails_bin + " -v")
+    print "no\n"
+    raise "rails command was not found"
+  end
 end
 
 # PLUGINS TO BE INSTALLED AFTER RAILS-COMMAND
@@ -44,6 +53,32 @@ else
 end
 =end
 
+# CHECK RAKE COMMAND
+print "checking rake... "
+if RUBY_PLATFORM =~ /mswin|mingw|bccwin/
+  $rakecommand = "rake.bat"
+  has_rake = system("#{$rakecommand} -V")
+else
+  IO.popen("which rake"){|io| $rake_path = io.read.strip}  
+  has_rake = ($rake_path != "")
+  $rakecommand = $ruby_bin + " " + $rake_path if has_rake
+  has_rake = system("#{$rakecommand} -V") if has_rake
+end
+unless has_rake
+  print "no\n"
+  raise '"rake" command is not found. Please install rake and set PATH.'
+end
+
+print "checking Rack... "
+has_rack = system($ruby_bin + " -r rubygems -e'require\"rack\"; p Rack::VERSION'")
+unless has_rack
+  print "no\n"
+  raise "Please install Rack version 1.1 from gem command (gem install rack -v 1.1)."
+end
+
+puts ""
+
+
 SERVER_TYPE_NAMES = ["1. private/group server",
                      "2. open-access server (enable user accounts)",
                      "3. open-access server (disable user accounts)"]
@@ -418,7 +453,7 @@ EOF
           skip_remote_plugin = false
 
           #plugincommand = "ruby script/plugin install --force"
-          plugincommand = "script/plugin"
+          plugincommand = $ruby_bin + " script/plugin"
   
           # $gfdnavi_plugins.each{|plgin| plugincommand << " " << plgin}
           # CHECK PROXY
@@ -560,11 +595,11 @@ def set_configure_files
             # CHANGE ADAPTER TO SQLite3
             line = "  adapter: sqlite3\n"
           elsif /^(\s*database:.*development)/ =~ line
-            line = "  database: db/development.sqlite3"
+            line = "  database: db/development.sqlite3\n"
           elsif /^(\s*database:.*test)/ =~ line
-            line = "  database: db/test.sqlite3"
+            line = "  database: db/test.sqlite3\n"
           elsif /^(\s*database:.*production)/ =~ line
-            line = "  database: db/production.sqlite3"
+            line = "  database: db/production.sqlite3\n"
           elsif /^(\s*username:)/ =~ line
             line = ""
           elsif /^(\s*password:)/ =~ line
@@ -666,17 +701,12 @@ EOF
   end
   # WHILE EXECUTION OF RAKE SETUP, WE NEED TO REPLY TO QUESTIONS
   # DO NOT OUTPUT TO /dev/null
-  if RUBY_PLATFORM =~ /mswin|mingw|bccwin/
-    rakecommand = "rake.bat"
-  else
-    rakecommand = "rake"
-  end
   unless $noquestions_rake
     rake_task = "setup"
   else
     rake_task = "setup_noquestions"
   end
-  unless system(rakecommand + " " + rake_task)
+  unless system($rakecommand + " " + rake_task)
     abort "failed to execute \"rake #{rake_task}\" at #{Dir.pwd}\n"
   end
 end
@@ -751,7 +781,7 @@ end
 # Windows native MySQL if MySQL with cygwin
 @params[:rdb_plf] = 1 if !(@params[:rdb_plf])
 @params[:salt] = [rand(64),rand(64),rand(64),rand(64),rand(64)].pack("C*").tr("\x00-\x3f","A-Za-z0-9./")
-@params[:email] = "mail@hoge.com" if !(@params[:email])
+@params[:email] = "gfdnavi@localhost.localdomain" if !(@params[:email])
 @params[:server_type] = 1 if !(@params[:server_type])
 @params[:rails_env] = "production" if !(@params[:rails_env])
 @params[:skip_rdb] = false
