@@ -2,13 +2,8 @@ module NumRu
   class NetCDF
     # For Marshal.dump. The argument "limit" is ignored.
     def _dump(limit)
-      path = self.path
-      if /^\// =~ path
-        abspath = path
-      else
-        abspath = Dir.pwd + '/' + path    # Inappropriate after chdir
-        raise("No such file: #{abspath}. Directory changed?") if !File.exist?(abspath)
-      end
+      abspath = File.expand_path(self.path)
+      raise("No such file: #{abspath}. Directory changed?") if !File.exist?(abspath)
       abspath
     end
 
