@@ -1,4 +1,4 @@
-# -*- coding: sjis -*-
+# -*- coding: cp932 -*-
 require "kconv"
 require 'opendapdir'
 require 'localdir'
@@ -98,10 +98,15 @@ module NumRu
         stun = $1
         since = DateTime.parse($2)
         tun = Units[stun]
-        sec = tun.convert( val, Units['seconds'] ).round + 1e-1
-               # ^ take "round" to avoid round error in sec
-               # (Note that %S below takes floor of seconds).
-        datetime = since + (sec/86400.0)
+        if tun =~ Units["month"]
+          mon = tun.convert(val, Units["month"])
+          datetime = since >> mon
+        else
+          sec = tun.convert( val, Units['seconds'] ).round + 1e-1
+                 # ^ take "round" to avoid round error in sec
+                 # (Note that %S below takes floor of seconds).
+          datetime = since + (sec/86400.0)
+        end
       else
         nil
       end
@@ -184,11 +189,11 @@ def after_save(obj)
   end
 end
 
-def t_comp(a,b)
+def t_comp(a,b) # ̖߂l^Ȃf[^XVƂdl
   return(nil) if a.nil? or b.nil?
-  if a.class == b.class
-    a > b
-  end
+  #if a.class == b.class # rłȂ̂nꂽG[fׂł
+    a > b # Time  ActiveSupport::TimeWithZone r\
+  #end
 end
 
 def parse_meta(path, node, force, attr, stremote)
@@ -205,6 +210,7 @@ def parse_meta(path, node, force, attr, stremote)
   fname = path + ".SIGEN"
   if File.exist?(fname)
     File.foreach(fname){|line|
+      line = Kconv.kconv(line, @charset)
       k, v = line.chop.split(":")
       register_kattr(k, v.strip, node) if v
       
@@ -419,7 +425,12 @@ def register_var(file, vname, parent, mtime, force, attr, stremote, ignore_error
   var.mtime = mtime
   var.path = rpath_var
   var.parent = parent.node
-  gphys = NumRu::GPhys::IO.open(file,vname)
+  begin
+    gphys = NumRu::GPhys::IO.open(file,vname)
+  rescue
+    puts "fail to register #{rpath_var}"
+    raise $!
+  end
   var.size = gphys.length
   node = var.node
   gphys.att_names.each{|aname|
@@ -446,14 +457,14 @@ def register_var(file, vname, parent, mtime, force, attr, stremote, ignore_error
     end
   end
   unless var.save
-    warn "failed to register variable: #{rpath}"
+    warn "failed to register variable: #{rpath_var}"
     if ignore_errors
       warn "  #{var.errors.full_messages}"
     else
       raise var.errors.full_messages
     end
   end
-  MSG.verbose("registrated variable: #{rpath}\n")
+  MSG.verbose("registrated variable: #{rpath_var}\n")
 end
 
 def register_image(path, org_path, meta, mtime, size, parent, force, attr, ignore_errors=true)
