@@ -7,35 +7,139 @@ require "gphys_gfdnavi"
 require "register_to_db"
 
 class VirtualData
+  ge544 = (NumRu::DCL::DCLVERSION.split(".").map{|v| v.to_i} <=> [5, 4, 4]) # CHECK DCL VERSION
+  DRAW_PROJECTION = \
+    [{:itr => 1, :description => "Rectangular uniform coordinate", :map_proj => false},
+     {:itr => 2, :description => "Semi-logarithmic coordinate (y axis)", :map_proj => false},
+     {:itr => 3, :description => "Semi-logarithmic coordinate (x axis)", :map_proj => false},
+     {:itr => 4, :description => "Logarithmic coordinate", :map_proj => false},
+     {:itr => 5, :description => "Polar coordinate", :map_proj => false},
+     {:itr => 6, :description => "Bipolar coordinate", :map_proj => false},
+     # 7 => "elliptic coordinate",
+     {:itr => 10, :description => "Equidistant cylindrical projection", :map_proj => true,
+       :map_fit =>    {:enable => true, :default => true}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 11, :description => "Mercator projection", :map_proj => true,
+       :map_fit =>    {:enable => true, :default => true},
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]},
+       :map_window => {:enable => true, :default => [-180, 180, -75, 75]},
+       :map_radius => {:enable => false}},
+     {:itr => 12, :description => "Mollweide projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 13, :description => "Hammer projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 14, :description => "Eckert VI projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 15, :description => "Kitada elliptic projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 16, :description => "Miller projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 17, :description => "Robinson projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 18, :description => "Sanson/sinusoidal projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 19, :description => "Van der Grinten projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => true, :default => [-180, 180, -90, 90]},
+       :map_radius => {:enable => false}},
+     {:itr => 20, :description => "Equidistant conical projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 21, :description => "Lambert equal-area conical projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 22, :description => "Lambert conformal conical projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 23, :description => "Bonne projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 24, :description => "Polyconic projection", :map_proj => true,
+       :map_fit =>    {:enable => false},
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 30, :description => "Orthographic projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 0, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 31, :description => "Polar stereo projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 32, :description => "Azimuthal equidistant projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 33, :description => "Lambert azimuthal equal-area projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 90}},
+     {:itr => 34, :description => "Gnomonic projection", :map_proj => true,
+       :map_fit =>    {:enable => false}, 
+       :map_axis =>   {:enable => true, :default => [0, 90, 0]}, 
+       :map_window => {:enable => false},
+       :map_radius => {:enable => true, :default => 60}}
+    ].reject{|prj| (ge544 < 0) && ([16, 17, 18, 19, 24, 34].include?(prj[:itr]))}
+  DRAW_PROJECTION_ITRS = DRAW_PROJECTION.map{|prj| prj[:itr]}
 
-  DRAW_PROJECTION = {1 => "rectangular uniform coordinate",
-                     2 => "semi-logarithmic coordinate (y axis)",
-                     3 => "semi-logarithmic coordinate (x axis)",
-                     4 => "logarithmic coordinate",
-                     5 => "polar coordinate",
-                     6 => "bipolar coordinate",
-#                     7 => "elliptic coordinate",
-                     10 => "equidistant cylindrical projection",
-                     11 => "Mercator's projection",
-                     12 => "Mollweide's projection",
-                     13 => "Hammer's projection",
-                     14 => "Eckert VI projection",
-                     15 => "Kitada's elliptic projection",
-                     20 => "equidistant conical projection",
-                     21 => "Lambert's equal-area conical projection",
-                     22 => "Lambert's conformal conical projection",
-                     23 => "Bonne's projection",
-                     30 => "orthographic projection",
-                     31 => "polar stereo projection",
-                     32 => "azimuthal equidistant projection",
-                     33 => "Lambert's azimuthal equal-area projection"
-                    }
+  def itr_to_projection(itr)
+    DRAW_PROJECTION.each{|proj| return proj if proj[:itr] == itr}
+    return nil
+  end
+
+  def get_map_proj_default(itr, key)
+    proj = itr_to_projection(itr)
+    proj.has_key?(key) ? proj[key][:default] : nil
+  end
 
   # GET COLOR MAP NUMBER AND DESCRIPTIONS
   color_maps = Hash.new
   NumRu::DCL::swcmll # READ THE COLOR-MAP LIST BEFORE GETTING DESCRIPTIONS
   NumRu::DCL::swqcmn.times{|i| color_maps[i+1] = NumRu::DCL::swqcmd(i+1)}
   COLOR_MAPS = color_maps # DEFINE AS A CONSTANT
+
+  # AVAILABLE DIAGRAM SIZES AND NAMES IN GUI
+  DRAW_SIZE = [{:size => [700, 700], :name => "L"},
+               {:size => [550, 550], :name => "M"},
+               {:size => [400, 400], :name => "S"},
+               {:size => [250, 250], :name => "XS"}]
   
   @@draw_options = {
     "x_axis" => {:type => "string"},
@@ -43,21 +147,22 @@ class VirtualData
     "z_axis" => {:type => "string"},
     "projection" => {:default => 1, :type => "int"},
     "pileup" => {:default => false, :type => "boolean"},
-    "size" => {:default => [400,400], :type => "array_int"},
+    "size" => {:default => DRAW_SIZE[2][:size], :type => "array_int"},
     "colormap" => {:default => 1, :type => "int"},
     "anim" => {:default => false, :type => "boolean", :optional => true},
     "anim_dim" => {:type => "string", :optional => true},
     "viewport" => {:default => [0.2, 0.8, 0.2, 0.8], :type => "array_float", :optional => true},
+    "window" => {:default => [nil, nil, nil, nil], :type => "array_float", :optional => true},
     "map" => {:default => false, :type => "boolean", :optional => true},
     "map_axis" => {:default => nil, :type => "array_float", :optional => true},
     "map_radius" => {:default => nil, :type => "float", :optional => true},
     "map_fit" => {:default => true, :type => "boolean", :optional => true},
-    "map_window" => {:default => "-180, 180, -75, 75", :type => "array_float", :optional => true},
+    "map_window" => {:default => nil, :type => "array_float", :optional => true},
     "variables_order" => {:default => {}, :type => "hash"},
   }
 
-  attr_accessor :original_nodes, :functions, :draw_method, :draw_slice
-  attr_reader :errors
+  attr_accessor :original_nodes, :functions, :draw_method, :draw_slice, :overlayed_plots
+  attr_reader :errors, :num_plots
   
 
   def self.value_to_array(value, val_type)
@@ -72,16 +177,16 @@ class VirtualData
       if value.empty?
         return nil
       else
-        ary = value.split(/,/)
+        ary = value.split(/,/) # blank space with zero length will be discarded
       end
     else
       ary = [value]
     end
     case val_type
     when :array_int, "array_int"
-      ary.collect!{|v| v.to_i}
+      ary.collect!{|v| (v.nil? || ((String === v) && (v.strip == ""))) ? nil : v.to_i} # blank space with non-zero length is treated as nil
     when :array_float, "array_float"
-      ary.collect!{|v| v.to_f}
+      ary.collect!{|v| (v.nil? || ((String === v) && (v.strip == ""))) ? nil : v.to_f} # blank space with non-zero length is treated as nil
     end
     return ary
   end
@@ -112,6 +217,7 @@ class VirtualData
     @draw_slice = nil
     @num_plots = nil
     @names = @original_nodes.collect{|node| node.name}
+    @overlayed_plots = Array.new
   end
 
   def name
@@ -151,16 +257,12 @@ class VirtualData
       names += subs.collect{|sub| "#{on}_#{sub}"}
     end
     @names = names
-    return true
+    @dimensions = @gphys = @gphys_dummy = nil # CLEAR CACHE
+    return self
   end
 
   def analysis(func, *args)
-    vd = self.deep_clone
-    res, msg = vd.analysis!(func, *args)
-    unless res
-      raise msg
-    end
-    return vd
+    return self.deep_clone.analysis!(func, *args)
   end
 
   def slice!(*ind)
@@ -192,13 +294,12 @@ class VirtualData
       @names = [@names] if String === @names
     end
     @num_vars = ind.length
-    return true
+    @dimensions = @gphys = @gphys_dummy = nil # CLEAR CACHE
+    return self
   end
 
   def slice(*ind)
-    vd = self.deep_clone
-    vd.slice!(*ind)
-    return vd
+    return self.deep_clone.slice!(*ind)
   end
   alias :[] :slice
 
@@ -208,21 +309,24 @@ class VirtualData
     elsif val.length == 1 && val[0].kind_of?(Hash)
       val_new = val[0].dup
       if @num_vars == 1
-        gp = self.to_gphys
-        axnames = gp.axnames
+        #gp = self.to_gphys ###
+        #axnames = gp.axnames ###
+        dims = self.dimensions #!!!
+        axnames = dims.map{|ax| ax["name"]} #!!!
         val_new.dup.each{|k,v|
           if !axnames.include?(k)
             val_new.delete(k)
           elsif v.is_a?(Range)
-            axis = gp.axis(k).pos.val
-            be = [v.begin.to_f,v.end.to_f]
+            #axis = gp.axis(k).pos.val ###
+            axis = dims[axnames.index(k)]["ary"] #!!!
+            be = [v.begin.to_f, v.end.to_f]
             be = [be[1], be[0]] if be[0] > be[1]
-            if ((axis.min.to_f-be[0]).abs <= (be[0] * 1.0e-5).abs) && ((axis.max.to_f-be[1]).abs <= (be[1] * 1.0e-5).abs)
+            if ((axis.min.to_f - be[0]).abs <= (be[0] * 1.0e-5).abs) && ((axis.max.to_f - be[1]).abs <= (be[1] * 1.0e-5).abs)
               val_new.delete(k)
             end
           end
         }
-        return true if val_new.empty?
+        return self if val_new.empty?
       end
       val_new.each{|k,v|
         case v
@@ -242,13 +346,12 @@ class VirtualData
       val_new = val.dup
     end
     @functions.push( {:type => :cut, :value => val_new} )
-    return true
+    @dimensions = @gphys = @gphys_dummy = nil # CLEAR CACHE
+    return self
   end
 
   def cut(*val)
-    vd = self.deep_clone
-    vd.cut!(*val)
-    return vd
+    return self.deep_clone.cut!(*val)
   end
 
   def plot!(dm,opts=Hash.new)
@@ -262,7 +365,7 @@ class VirtualData
     dm.draw_method_options.each{|dmop|
       on = dmop.name
       val = opts.delete(on)
-      if val.nil? || val=="nil" || val==""
+      if val.nil? || ((String === val) && (val.empty? || val == "nil"))
         val =  dmop.optional ? nil : dmop.default
       end
       unless val.nil?
@@ -272,7 +375,7 @@ class VirtualData
     @@draw_options.each{|on,v|
       # When val == false, that parameter must be sent to draw methods.
       # Only nil and blank can be removed.
-      unless (val=opts.delete(on)).nil? || val=="nil" || val==""
+      unless (val = opts.delete(on)).nil? || ((String === val) && (val.empty? || val == "nil"))
         opts_new[on] = param_cast(val, v[:type])
       end
     }
@@ -280,20 +383,32 @@ class VirtualData
       raise "wrong options were specified: #{opts.keys.join(", ")}"
     end
     @draw_method = [dm,opts_new]
-    @num_vars = @num_vars/dm.nvars
+    @num_vars /= dm.nvars
     @num_plots = @num_vars
     if opts_new["pileup"]
       @num_vars = 1
     end
-    return true
+    return self
   end
 
   def plot(dm, opts=Hash.new)
-    vd = self.deep_clone
-    vd.plot!(dm, opts)
-    return vd
+    return self.deep_clone.plot!(dm, opts)
   end
 
+  def overlay!(plot)
+    plot = plot[0] if plot.is_a?(NumRu::GfdnaviData::ArrayLocal)
+    plot = plot.get_object if plot.is_a?(NumRu::GfdnaviData::ImageLocal)
+    unless plot.is_a?(VirtualData) && (plot.type == "draw")
+      raise ArgumentError, "argument is not compatible with overlay: #{plot.inspect}"
+    end
+    @overlayed_plots ||= Array.new
+    @overlayed_plots.push(plot)
+    return self
+  end
+
+  def overlay(plot)
+    return self.deep_clone.overlay!(plot)
+  end
 
   def type
     @draw_method ? "draw" : @functions.length > 0 ? "analysis" : "node"
@@ -440,8 +555,9 @@ class VirtualData
     !@errors.any?
   end
 
-  def to_gphys
-    res = get_proc(nil, true)
+  def to_gphys(dummy=false)
+#    return @gphys if @gphys # GET CACHE
+    res = get_proc(nil, true, dummy)
     if res[0]
       res = execute(res[1])
       if res[0]
@@ -452,6 +568,7 @@ class VirtualData
         unless obj.kind_of?(NumRu::GPhys)
           raise "BUG (#{obj.class} is not a NumRu::GPhys)"
         end
+#        @gphys = obj unless dummy # PUT CACHE
         return obj
       end
     end
@@ -461,12 +578,16 @@ class VirtualData
   def png
     if @draw_method
       prefix = File.join(GFDNAVI_DIAGRAM_CACHE_PATH)
-      files, msg = get(prefix)
+      files, msg = get(prefix) # the variable "files" is always an Array
       case files
       when Array
-        return files.collect{|file| File.read(file)}
-      when String
-        return File.read(files)
+        if files.length == 1
+          return File.open(files[0], "rb"){|f| f.read}
+        else
+          return files.collect{|file| File.open(file, "rb"){|f| f.read}}
+        end
+      when String # maybe nonsense
+        return File.open(files, "rb"){|f| f.read}
       else
         raise "BUG: #{msg}, #{files.inspect}"
       end
@@ -476,16 +597,14 @@ class VirtualData
   alias :to_png :png
 
   def dimensions
-    return @dims if @dims
+    return @dimensions if @dimensions
     dims = Array.new
     g = get_grid
     g.rank.times{|i|
       crd = g.axis(i).pos
-      hash = Hash.new
-      hash["name"] = crd.name
-      hash["ary"] = crd.val
-      hash["units"] = crd.get_att("units")
-      dims.push hash
+      dims.push({"name" => crd.name,
+                  "ary" => crd.val,
+                  "units" => crd.get_att("units")})
     }
     @dimensions = dims
   end
@@ -493,15 +612,15 @@ class VirtualData
   def path
     return @path if @path
     str = @original_nodes.collect{|on| on.path}.join(",")
-    str = "/[#{str}]" if @original_nodes.length > 1
+    str = "/[" << str << "]" if @original_nodes.length > 1
     @functions.each_with_index{|f,i|
       case f[:type]
       when :func
         /\A\/usr\/([^\/]+)\/functions\/(.+)\z/ =~ f[:func].path
         fname = $2
         fname << ","+$1 unless $1 == "root"
-        args = f[:args] ? ";" + f[:args].join(",") : ""
-        str << "/analysis(#{fname}#{args})"
+        args = f[:args] ? ";" << f[:args].join(",") : ""
+        str << "/analysis(" << fname << args << ")"
       when :index
         if i==0
           ary = Array.new
@@ -510,12 +629,12 @@ class VirtualData
           end
           str = ary.collect{|on| on.path}.join(",")
         else
-          str << "[#{f[:index].join(',')}]"
+          str << "[" << f[:index].join(',') << "]"
         end
       when :cut
         a = f[:value]
         a = a.collect{|k,v| "#{k}=>#{v}"} if a.kind_of?(Hash)
-        str << "/cut(#{a.join(',')})"
+        str << "/cut(" << a.join(',') << ")"
       else
         raise "invalid type"
       end
@@ -523,17 +642,20 @@ class VirtualData
     if @draw_method
       /\A\/usr\/([^\/]+)\/draw_methods\/(.+)\z/ =~ @draw_method[0].path
       dname = $2
-      dname << ","+$1 unless $1 == "root"
+      dname << "," << $1 unless $1 == "root"
       opts = @draw_method[1]
       unless opts && Hash === opts && !opts.empty?
         sopt =  ""
       else
-        sopt =  ";" + NumRu::GfdnaviData.hash_to_str(opts)
+        sopt =  ";" << NumRu::GfdnaviData.hash_to_str(opts)
       end
-      str << "/plot(#{dname}#{sopt})"
+      str << "/plot(" << dname << sopt << ")"
     end
     if @draw_slice
-      str << "[#{@draw_slice.join(",")}]"
+      str << "[" << @draw_slice.join(",") << "]"
+    end
+    if @overlayed_plots.length > 0
+      str = "/[" << @overlayed_plots.map{|obj| obj.path}.unshift(str).join(",") << "]/overlay()"
     end
     @path = str
     return str
@@ -570,21 +692,21 @@ class VirtualData
 
   def to_hash(opts={})
     uri_prefix = opts[:uri_prefix]
+    hash = Hash.new
+    hash["path"] = path
     if @draw_method
       if array?
-        hash = Hash.new
         @num_vars.times do |i|
           hash[i] =  {"url" => "#{File.join(uri_prefix,"data",path)}[#{i}]"}
         end
         hash["type"] = "array_image"
         hash["length"] = @num_vars
-        hash["path"] = path
         hash["slice"] = {
           "url" => File.join(uri_prefix, "data", "#{path}[{index}]"),
           "index" => "{index}"
         }
         return hash
-      else
+      else # not an array => image
 #        str = png
 =begin
         hash = {
@@ -594,14 +716,10 @@ class VirtualData
           "path" => "#{path}[0]"
         }
 =end
-        hash = {
-          "path" => path,
-          "type" => "image"
-        }
+        hash["type"] = "image"
         return hash
       end
-    else
-      hash = Hash.new
+    else # no @draw_method
       if array?
         @num_vars.times do |i|
           hash[i] = {"url" => "#{File.join(uri_prefix,"data",path)}[#{i}]"}
@@ -614,12 +732,12 @@ class VirtualData
         }
       else
         hash["type"] = "variable"
+        hash["axes"] = dimensions
       end
       hash["cut"] = {
         "url" => File.join(uri_prefix, "data", path, "cut({arguments})"),
         "arguments" => "{arguments}"
       }
-      hash["path"] = path
       hash["plot"] = {
         "url" => File.join(uri_prefix, "data", path, "plot({draw_method_name};{draw_method_options})"),
         "draw_method_name" => "{draw_method_name}",
@@ -641,20 +759,27 @@ class VirtualData
     suffix = opts[:suffix]
     code = ""
     unless minimal
-      code +=<<-EOF
+      code << <<-EOF
 require 'numru/gfdnavi_data'
 include NumRu
 
       EOF
     end
     get_path = Proc.new do |on, only_one, suff|
-      case on
+      case on # an item in @original_nodes
       when Variable
-        str = "GfdnaviData.open(\"#{File.join(uri_prefix, "data", on.path)}\")"
+        if uri_prefix
+          str = "GfdnaviData.open(\"#{File.join(uri_prefix, "data", on.path)}\")"
+        else
+          str = "GfdnaviData.open(\"#{on.path}\")"
+        end
+        str = "data#{suff} = #{str}" #if minimal
       else
-        str = on.to_rb(opts.dup.update(:minimal=>true, :suffix=>suff))
+        str = ""
+        str << "data#{suff} = begin \n" if minimal
+        str << indent_code(on.to_rb(opts.dup.update(:minimal=>true, :suffix=>suff)), 2)
+        str << "end \n" if minimal
       end
-      str = "data#{suffix} = #{str}" if minimal
       str
     end
     if @original_nodes.length == 1
@@ -662,11 +787,12 @@ include NumRu
     else
       a = Array.new
       @original_nodes.each_with_index do |on,i|
-        code << get_path.call(on,false,i) << "\n"
-        a.push "data#{i}"
+        suff = suffix.to_s + "_" + i.to_s
+        code << get_path.call(on, false, suff) << "\n"
+        a.push "data#{suff}"
       end
-      str = a.join(",")
-      code << "data#{suffix} = GfdnaviData::Array[#{str}]\n"
+      str = a.join(", ")
+      code << "data#{suffix} = GfdnaviData::Array[#{str}] \n"
     end
 
 
@@ -675,7 +801,7 @@ include NumRu
       when :func
         /\A\/usr\/([^\/]+)\/functions\/(.+)\z/ =~ f[:func].path
         fname = $2
-        fname << ","+$1 unless $1 == "root"
+        fname << "," << $1 unless $1 == "root"
         args = f[:args] ? ",'#{f[:args].join("','")}'" : ""
         code << "data#{suffix} = data#{suffix}.analysis('#{fname}'#{args})\n"
       when :index
@@ -691,7 +817,7 @@ include NumRu
     if @draw_method
       /\A\/usr\/([^\/]+)\/draw_methods\/(.+)\z/ =~ @draw_method[0].path
       dname = $2
-      dname << ","+$1 unless $1 == "root"
+      dname << "," << $1 unless $1 == "root"
       opts = @draw_method[1]
       unless opts && Hash === opts && !opts.empty?
         sopt =  ""
@@ -705,10 +831,23 @@ include NumRu
       end
       code << "data#{suffix} = data#{suffix}.plot('#{dname}'#{sopt})\n"
     end
+
     if @draw_slice
       code << "data#{suffix} = data#{suffix}[#{@draw_slice.join(",")}]\n"
     end
 
+    if @overlayed_plots.length > 0
+      code << "plots = [data] \n"
+      @overlayed_plots.each_with_index{|ovrly, i|
+        code << "\n# Overlayed plot #{i}\n\n"
+        code << "def overlayed_plot_#{i}\n"
+        code << indent_code(ovrly.to_rb(:uri_prefix => uri_prefix, :minimal => true, :suffix => suffix), 2)
+        code << "end\n"
+        code << "plots.push overlayed_plot_#{i} \n"
+      }
+      code << "data = GfdnaviData::Array[*plots].overlay \n"
+    end
+
     unless minimal
       code << "\n\n=begin\n"
       if @num_vars == 1
@@ -745,11 +884,63 @@ EOF
     return code
   end
 
+  def indent_code(code, indent = 2)
+    code.split("\n").map{|l| " " * indent + l}.join("\n") << "\n"
+  end
+  private :indent_code
+
   # get all Variables from VirtualData object.
   def virtual_nodes
     NumRu::GfdnaviData::Local.get_variable_nodes(@original_nodes)
   end
 
+  def get_grid
+#    return @gphys.instance_variable_get(:@grid) if @gphys # GET CACHE
+    return @gphys_dummy.instance_variable_get(:@grid) if @gphys_dummy # GET CACHE
+    vars = Array.new
+    script = gen_code(nil, vars, 0, true)
+    gphyses = vars.collect{|node|
+      node = node.entity if Node === node
+      node = node.get_object if NumRu::GfdnaviData::VariableLocal === node
+      case node
+      when Variable
+        gphys = node.to_gphys(true) # create a GPhysDummy when the arg is true
+        grid = gphys.instance_variable_get(:@grid)
+      when VirtualData
+        grid = node.get_grid
+      else
+        raise "not supported"
+      end
+      NumRu::GPhysDummy.new(grid, NumRu::VArrayDummy.new)
+    }
+=begin
+    Thread.new{
+      $SAFE = 2
+      begin
+        eval script
+      rescue => e
+        Thread.main.raise e
+      end
+    }.join
+=end
+    flag, msg, out = execute(Proc.new{eval_script(script, binding); gphyses})
+    if flag
+      gphyses =  Marshal.load(out)
+    else
+      raise msg
+    end
+    gphyses = [gphyses] unless gphyses.is_a?(Array)
+    unless gphyses.length == 1
+      raise "number of gphyses is not one"
+    end
+    @gphys_dummy = gphyses[0] # PUT CACHE
+    return gphyses[0].instance_variable_get(:@grid)
+  end
+
+  def get_vizshot_proc(basename, flag=false, dummy=false, slave=false)
+    get_proc(basename, flag, dummy, slave) if @draw_method
+  end
+
   protected
 
   def deep_clone
@@ -760,27 +951,46 @@ EOF
     vd.instance_variable_set(:@draw_method, @draw_method)
     vd.instance_variable_set(:@draw_slice, @draw_slice)
     vd.instance_variable_set(:@names, @names.dup)
+    vd.instance_variable_set(:@overlayed_plots, @overlayed_plots.dup)
+    vd.instance_variable_set(:@dimensions, @dimensions.dup) if @dimensions
+    vd.instance_variable_set(:@gphys, @gphys.dup) if @gphys
+    vd.instance_variable_set(:@gphys_dummy, @gphys_dummy.dup) if @gphys_dummy
     return vd
   end
 
   private
 
+  def eval_script(script, bind)
+    begin
+      eval script, bind, "script"
+    rescue
+      # add line number to the left of each line
+      script.split("\n").each_with_index do |line, n|
+        STDERR.print "%3d: "%(n+1) << line << "\n"
+      end
+      raise $!
+    end
+  end
+
 
   def param_cast(val, type)
-    type = type.to_s if type.is_a?(Symbol)
+    type_org = type
+    type = type.to_sym if type.is_a?(String)
     case type
-    when "int"
+    when :int
       return val.to_i
-    when "float"
+    when :float
       return val.to_f
-    when "boolean"
+    when :boolean
       return val == "1" || val == "t" || val == "true" || val == true
-    when /\Aarray/
-      return self.class.value_to_array(val, type)
-    when "string", "hash"
+    when :string, :hash
       return val
     else
-      raise "invalid type: #{type} #{val}"
+      if /\Aarray/ =~ type_org
+        return self.class.value_to_array(val, type)
+      else
+        raise "invalid type: #{type} #{val}"
+      end
     end
   end
 
@@ -802,6 +1012,7 @@ EOF
     return dc
   end
 
+=begin
   def get_grid
     vars = Array.new
     script = gen_code(nil, vars, 0, true)
@@ -819,21 +1030,27 @@ EOF
       end
       NumRu::GPhysDummy.new(grid, NumRu::VArrayDummy.new)
     }
-    Thread.new{
-      $SAFE = 2
-      begin
-        eval script
-      rescue => e
-        Thread.main.raise e
-      end
-    }.join
+    flag, msg, out = execute(Proc.new{eval script; gphyses})
+    if flag
+      gphyses =  Marshal.load(out)
+    else
+      raise msg
+    end
+    gphyses = [gphyses] unless gphyses.is_a?(Array)
     unless gphyses.length == 1
       raise "number of gphyes is not one"
     end
     return gphyses[0].instance_variable_get(:@grid)
   end
+=end
 
-  def get_proc(basename, flag=false)
+  def check_opts_array(ary, len, msg)
+    unless (Array === ary) && (ary.length == len)
+      raise ArgumentError, "option #{msg} must be an Array of length #{len}: #{ary.inspect}"
+    end
+  end
+
+  def get_proc(basename, flag=false, dummy=false, slave=false)
     if @draw_method && !flag
       dm, opts = @draw_method
       opts = opts.dup
@@ -843,79 +1060,54 @@ EOF
       plot[:method] = dm.vizshot_method.to_sym
 
       # PARSE OPTIONS ##########################
-      size = opts.delete("size")
-      if size
-        unless Array === size && size.length == 2
-          raise "option size must be array of length 2: #{size.inspect}"
-        end
-        size = size.collect{|c| c.to_i}
-      else
-        size = @@draw_options["size"][:default]
-      end
+      size = opts.delete("size") || @@draw_options["size"][:default]
+      check_opts_array(size, 2, "size")
+      size = size.collect{|c| c.to_i}
 
       colormap = opts.delete("colormap") || @@draw_options["colormap"][:default]
+      unless COLOR_MAPS[colormap]
+        raise ArgumentError, "option colormap is invalid: #{colormap}"
+      end
 
-      projection = opts.delete("projection")
-      if projection
-        projection = projection.to_i
-        unless DRAW_PROJECTION.has_key?(projection)
-          raise "option projection number is invalid: #{projection}"
+      itr = (opts.delete("projection") || @@draw_options["projection"][:default]).to_i
+      unless DRAW_PROJECTION_ITRS.include?(itr)
+        raise ArgumentError, "option projection is invalid: #{itr}"
+      end
+
+      if(viewport = opts.delete("viewport") || @@draw_options["viewport"][:default])
+        check_opts_array(viewport, 4, "viewport")
+        viewport = viewport.collect{|c| c.to_f}
+        unless viewport.min >= 0 && viewport.max <= 1 && viewport[0] < viewport[1] && viewport[2] < viewport[3]
+          raise ArgumentError, "option viewport is invalid: #{viewport.inspect}"
         end
-      else
-        projection = @@draw_options["projection"][:default]
       end
 
-      viewport = opts.delete("viewport")
-      if viewport
-        if Array === viewport
-          viewport = viewport.collect{|c| c.to_f}
-          unless viewport.min >= 0 && viewport.max <= 1 && viewport[0] < viewport[1] && viewport[2] < viewport[3]
-            raise "option viewport is invalid: #{viewport.inspect}"
-          end
-        else
-          raise "option viewport is invalid: #{viewport.inspect}"
-        end
-      else
-        viewport = @@draw_options["viewport"][:default]
+      if(window = opts.delete("window") || @@draw_options["window"][:default])
+        check_opts_array(window, 4, "window")
+        window = window.collect{|c| c.nil? ? nil : c.to_f}
       end
 
-      map_axis = opts.delete("map_axis")
-      if map_axis
-        if Array === map_axis
-          map_axis = map_axis.collect{|c| c.to_f}
-          if map_axis.length == 0
-            map_axis = @@draw_options["map_axis"][:default]
-          elsif map_axis.length < 3
-            raise "length of option map_axis must be 3: #{map_axis.inspect}"
-          elsif map_axis.length > 3
-            map_axis = map_axis[0..2]
-          end
-        end
-      else
-        map_axis = @@draw_options["map_axis"][:default]
+      if(get_map_proj_default(itr, :map_axis))
+        map_axis = opts.delete("map_axis") || get_map_proj_default(itr, :map_axis)
+        check_opts_array(map_axis, 3, "map_axis")
+        3.times{|i|
+          map_axis[i] ||= get_map_proj_default(itr, :map_axis)[i]
+          map_axis[i] = map_axis[i].to_f
+        }
       end
 
-      map_radius = opts.delete("map_radius")
-      if map_radius
-      else
-        map_radius = @@draw_options["map_radius"][:default]
-      end
+      map_radius = opts.delete("map_radius") || get_map_proj_default(itr, :map_radius)
 
       map_fit = opts.delete("map_fit")
-      if map_fit.nil?
-        map_fit = @@draw_options["map_fit"][:default]
-      end
+      map_fit = get_map_proj_default(itr, :map_fit) if map_fit.nil? # map_fit is boolean
 
-      map_window = opts.delete("map_window")
-      if map_window
-        if Array === map_window
-          map_window = map_window.collect{|c| c.to_f}
-          unless map_window.length == 4
-            raise "length of option map_window is invalid: #{map_window.inspect}"
-          end
-        end
-      else
-        map_window = @@draw_options["map_window"][:default]
+      if(get_map_proj_default(itr, :map_window))
+        map_window = opts.delete("map_window") || get_map_proj_default(itr, :map_window)
+        check_opts_array(map_window, 4, "map_window")
+        4.times{|i|
+          map_window[i] ||= get_map_proj_default(itr, :map_window)[i]
+          map_window[i] = map_window[i].to_f
+        }
       end
       
       if y_axis = opts.delete("y_axis") # NOT 1D-PLOT
@@ -924,6 +1116,7 @@ EOF
       end
       vo = nil
       dm.nvars > 1 && (vo = opts.delete("variables_order"))
+      vo = vo.sort.collect{|val| val[1]} if vo.is_a?(Hash) # TENTATIVE WORKAROUND
       vo = [vo] if vo && !(vo.is_a?(Array) && vo[0].is_a?(Array))
       # END PARSE OPTIONS ######################
 
@@ -941,13 +1134,21 @@ EOF
                                         :iheight => size[1],
                                         :iclrmap => colormap,
                                         :basename => basename)
-        viz.set_fig("itr" => projection, 
-                    "viewport" => viewport, 
-                    'map_axis' => map_axis,
-                    'map_radius' => map_radius,
-                    'map_fit' => map_fit,
-                    'map_window' => map_window) 
-        viz.set_tone("auto" => (projection != 5 && projection <= 10)) 
+        unless slave
+          viz.set_fig("itr" => itr, 
+                      "viewport" => viewport, 
+                      "window" => window, 
+                      'map_axis' => map_axis,
+                      'map_radius' => map_radius,
+                      'map_fit' => map_fit,
+                      'map_window' => map_window) 
+        end
+        viz.set_tone("auto" => (itr != 5 && itr <= 10)) 
+        @overlayed_plots.each{|ovrly|
+          if ovrly.num_plots != 1 # for the moment
+            raise "number of plots to be overlayed is not one."
+          end
+        }
         @num_plots.times{|i|
           plot[:variables] = vars[i].collect{|var| var.path}
           plot[:script] = script + "gphyses = gphyses[#{dm.nvars*i},#{dm.nvars}] if gphyses.is_a?(Array)\n"
@@ -976,11 +1177,19 @@ EOL
           end
           pileup = opts["pileup"]
           pileup = (pileup==true || pileup==1)
-          plot[:newfrm] = i==0 || pileup==false
+          plot[:newfrm] = (i==0 || pileup==false) && !slave
           viz.plot(plot.dup)
+          @overlayed_plots.each{|ovrly|
+            res = ovrly.get_vizshot_proc(basename, flag, dummy, true)
+            viz = viz.add(res[1].call) if res[0]
+          }
         }
-        viz.execute(:image_dump => true)
-        nil
+        if slave
+          viz
+        else
+          viz.execute(:image_dump => true)
+          nil
+        end
       }
     else
       vars = Array.new
@@ -992,9 +1201,14 @@ EOL
         gphyses = vars.collect{|var|
           NumRu::GPhys::IO.open(var.fname,var.vname)
         }
+        if dummy
+          gphyses.collect{|gp| 
+            NumRu::GPhysDummy.new(gp.instance_variable_get(:@grid), NumRu::VArrayDummy.new)
+          }
+        end
         Thread.new{
 #          $SAFE = 2
-          eval script
+          eval_script(script, binding)
         }.join
 
         unless flag
@@ -1095,7 +1309,7 @@ EOF
       when :cut
         a = func[:value]
         a = a.collect{|k,v| "'#{k}'=>#{v}"} if a.kind_of?(Hash)
-        script << <<EOF
+        script << <<"EOF"
     if gphyses#{id}.kind_of?(Array)
       gphyses#{id}.collect!{|gphys| gphys.cut(#{a.join(",")})}
     else
@@ -1114,6 +1328,13 @@ EOF
     return script
   end
 
+  begin
+    pid = fork{}
+    Process.waitpid(pid)
+    FORK_SUPPORTED = true
+  rescue NotImplementedError
+    FORK_SUPPORTED = false
+  end
 
   def execute(proc, dir=nil, nice=19)
     proc1 = Proc.new {
@@ -1124,16 +1345,17 @@ EOF
       rescue TypeError
         if obj.is_a?(NumRu::GPhys)
           Marshal.dump(obj.copy) # not NArray nor NetCDF
+        elsif obj.is_a?(Array) && obj[0].is_a?(NumRu::GPhys)
+          Marshal.dump(obj.map{|o| o.copy}) # not NArray nor NetCDF
+        else
+          raise $!
         end
       end
     }
-    case Config::CONFIG["host_os"]
-    when /linux/, /darwin/
+    if FORK_SUPPORTED
       flag, msg, err, out = execute_fork(proc1, nice)
-    when /win32/, /cygwin/
-      flag, msg, err, out = execute_thread(proc1)
     else
-      raise "not supported"
+      flag, msg, err, out = execute_thread(proc1)
     end
     if msg
       msg += err
@@ -1225,6 +1447,5 @@ EOF
     return [flag, msg, err, out]
   end
 
-
 end
 
