@@ -15,10 +15,10 @@ function setCookie(name,value,expire){
 function getCookie(name){
   var search = name + '=';
   if (document.cookie.length>0) {
-    offset = document.cookie.indexOf(search);
+    var offset = document.cookie.indexOf(search);
     if (offset != -1){
       offset += search.length;
-      end     = document.cookie.indexOf(';',offset);
+      var end = document.cookie.indexOf(';',offset);
       if(end == -1)
         end = document.cookie.length;
       return unescape(document.cookie.substring(offset,end));
@@ -47,21 +47,21 @@ PopupMenu.prototype = {
       menu.style.top = Event.pointerY(e)-5 + 'px';
       return;
     }
-    html = '<div id="'+id+'" class="popup_menu" style="display:none">';
-    html += '<table cellspacing="0" cellpadding="0" border="1" bordercolor="black">'
-    html += '<tr id="'+hid+'" border="0" style="background-color:#ddeeff;cursor:move;">';
-    html += '<td>';
-    html += '<div align="left" style="float:left">';
+    var html = '<div id="'+id+'" class="popup_menu" style="display:none">'
+          + '<table cellspacing="0" cellpadding="0" border="1" bordercolor="black">'
+          + '<tr id="'+hid+'" border="0" style="background-color:#ddeeff;cursor:move;">'
+          + '<td>'
+          + '<div align="left" style="float:left">';
     if (this.title)
       html += this.title;
-    html += '</div>';
-    html += '<div align="right"><a href="#" onClick="Element.remove($(\''+id+'\'));"><img src="' + gfdnaviUrlRoot + '/images/x.gif" alt="X" class="delete"/></a></div>';
-    html += '</td></tr>';
-    html += '<tr><td>';
-    html += '<div style="padding:5px">' + this.html  + '</div>';
-    html += '</td></tr>';
-    html += '</table>';
-    html += '</div>';
+    html += '</div>'
+          + '<div align="right"><img src="' + gfdnaviUrlRoot + '/images/x.gif" alt="X" class="delete" onClick="Element.remove($(\''+id+'\'));"/></div>'
+          + '</td></tr>'
+          + '<tr><td>'
+          + '<div style="padding:5px">' + this.html  + '</div>'
+          + '</td></tr>'
+          + '</table>'
+          + '</div>';
 
     new Insertion.Bottom(Element.extend(document.body), html);
     menu = $(id);
@@ -82,7 +82,7 @@ PopupMenu.prototype = {
   closeMenu: function(e) {
     Element.remove(this.id);
   }
-}
+};
 
 var BenchMark = Class.create();
 BenchMark.prototype = {
@@ -127,16 +127,16 @@ var html_hidden = " <font color='red'><b>(hidden currently)</b></font> ";
 var temp_save_str = "";
 
 function helpLinkHilit(id, self) {
-  obj = $(id);
+  var obj = $(id);
   if(obj && testElementVisible(obj)){
     obj.style.backgroundColor=highlightBgColor;
   } else {
-    temp_save_str = self.innerHTML
+    temp_save_str = self.innerHTML;
     self.innerHTML = temp_save_str + html_hidden;
   }
 }
 function helpLinkUnhilit(id, self) {
-  obj = $(id);
+  var obj = $(id);
   if(obj && testElementVisible(obj)){
     obj.style.backgroundColor=normalBgColor;
   } else {
@@ -145,7 +145,7 @@ function helpLinkUnhilit(id, self) {
 }
 
 function testElementVisible(obj) {
-  elm = obj;
+  var elm = obj;
   while (elm) {
     if (elm == document)
       return true;
@@ -162,12 +162,12 @@ function bgFlash(id){
 
 //copy of knowledge.js
 function showCommentListShort () {
-    comment_list_short = document.getElementById("comment_list_short")
-    comment_list_short_button = document.getElementById("comment_list_short_button")
-    comment_list_hide = document.getElementById("comment_list_hide")
-    comment_list_hide_button = document.getElementById("comment_list_hide_button")
-    comment_list_all = document.getElementById("comment_list_all")
-    comment_list_all_button = document.getElementById("comment_list_all_button")
+    var comment_list_short = document.getElementById("comment_list_short");
+    var comment_list_short_button = document.getElementById("comment_list_short_button");
+    var comment_list_hide = document.getElementById("comment_list_hide");
+    var comment_list_hide_button = document.getElementById("comment_list_hide_button");
+    var comment_list_all = document.getElementById("comment_list_all");
+    var comment_list_all_button = document.getElementById("comment_list_all_button");
     
     comment_list_short.style.display = "block";
     comment_list_short_button.style.borderStyle = "solid";
@@ -178,12 +178,12 @@ function showCommentListShort () {
 }
 
 function showCommentListHide () {
-    comment_list_short = document.getElementById("comment_list_short")
-    comment_list_short_button = document.getElementById("comment_list_short_button")
-    comment_list_hide = document.getElementById("comment_list_hide")
-    comment_list_hide_button = document.getElementById("comment_list_hide_button")
-    comment_list_all = document.getElementById("comment_list_all")
-    comment_list_all_button = document.getElementById("comment_list_all_button")
+    var comment_list_short = document.getElementById("comment_list_short");
+    var comment_list_short_button = document.getElementById("comment_list_short_button");
+    var comment_list_hide = document.getElementById("comment_list_hide");
+    var comment_list_hide_button = document.getElementById("comment_list_hide_button");
+    var comment_list_all = document.getElementById("comment_list_all");
+    var comment_list_all_button = document.getElementById("comment_list_all_button");
     
     comment_list_short.style.display = "none";
     comment_list_short_button.style.borderStyle = "none";
@@ -194,12 +194,12 @@ function showCommentListHide () {
 }
 
 function showCommentListAll () {
-    comment_list_short = document.getElementById("comment_list_short")
-    comment_list_short_button = document.getElementById("comment_list_short_button")
-    comment_list_hide = document.getElementById("comment_list_hide")
-    comment_list_hide_button = document.getElementById("comment_list_hide_button")
-    comment_list_all = document.getElementById("comment_list_all")
-    comment_list_all_button = document.getElementById("comment_list_all_button")
+    var comment_list_short = document.getElementById("comment_list_short");
+    var comment_list_short_button = document.getElementById("comment_list_short_button");
+    var comment_list_hide = document.getElementById("comment_list_hide");
+    var comment_list_hide_button = document.getElementById("comment_list_hide_button");
+    var comment_list_all = document.getElementById("comment_list_all");
+    var comment_list_all_button = document.getElementById("comment_list_all_button");
       
     comment_list_short.style.display = "none";
     comment_list_short_button.style.borderStyle = "none";
@@ -210,6 +210,6 @@ function showCommentListAll () {
 }
 
 function enableButton (button_id) {
-    button = document.getElementById(button_id);
+    var button = document.getElementById(button_id);
     button.style.display = "block";
 }
