@@ -24,7 +24,7 @@ Object.extend(Dial.prototype, {
     Draggable.prototype.updateDrag.apply(this, arguments);
   },
   endDrag: function(event, pointer) {
-    if (this.handler) this.handler();
+    if (this.handler) this.handler(event);
     Draggable.prototype.endDrag.apply(this, arguments);
   }
 });
@@ -33,15 +33,16 @@ var Slider = Class.create();
 Slider.prototype = {
   initialize: function(name, width, text_size, ary, make_right, left_default, right_default) {
 
-    element = $(name);
+    var element = $(name);
 
     var left_obj = new Object();
     this.left_obj = left_obj;
 
     left_obj.text_id = name+"_left_text";
     left_obj.dial_id = name+"_left_dial";
+    var right_obj;
     if(make_right) {
-      var right_obj = new Object();
+      right_obj = new Object();
       this.right_obj = right_obj;
       right_obj.text_id = name+"_right_text";
       right_obj.dial_id = name+"_right_dial";
@@ -50,8 +51,8 @@ Slider.prototype = {
     this.free_obj = free_obj;
     free_obj.dial_id = name+"_free_dial";
 
-    back_id = name+"_back";
-    td_id = name+"_td";
+    var back_id = name+"_back";
+    var td_id = name+"_td";
     this.back_id = back_id;
 
     var text_var;
@@ -63,18 +64,18 @@ Slider.prototype = {
       text_var = ary.first();
     html += '<td><input type="text" name="' + name + '[min]" id="' + left_obj.text_id + '" size="' + text_size + '" value="' + text_var +'"/></td>';
     html += '<td id="' + td_id + '">';
-    html += '<div id="' + back_id + '" style="width:' + width +';height:' + 0 + ';"><hr style="position:relative;top:1ex"/></div>';
+    html += '<div id="' + back_id + '" style="width:' + width + 'px; height:' + 0 + 'px;"><hr style="position:relative;top:1ex"/></div>';
     html += '<span id="' + left_obj.dial_id + '" style="position:relative;"></span>';
     if(make_right)
       html += '<span id="' + right_obj.dial_id + '" style="position:relative;"></span>';
     html += '<span id="' + free_obj.dial_id + '" style="position:relative;display:none;"></span>';
-    html += '</td>'
+    html += '</td>';
     if(make_right) {
       if(right_default != null)
         text_var = right_default;
       else
         text_var = ary.last();
-      html += '<td><input type="text" name="' + name + '[max]" id="' + right_obj.text_id + '" size="' + text_size + '" value="' + text_var + '" /><td>'
+      html += '<td><input type="text" name="' + name + '[max]" id="' + right_obj.text_id + '" size="' + text_size + '" value="' + text_var + '" /><td>';
     }
     html += '</tr></table>';
     element.update(html);
@@ -122,26 +123,26 @@ Slider.prototype = {
       starteffect: null,
       endeffect: null
     };
-    left_dial = new Dial(left_obj.dial_dom, options);
+    var left_dial = new Dial(left_obj.dial_dom, options);
     left_dial.min = 0;
     left_dial.max = ary.length-1;
     left_dial.text = left_obj.text_dom;
     left_dial.slider = this;
     left_dial.relative_offset = 0;
     left_dial.index = 0;
-    left_dial.handler = function() { if (this.slider.leftHandler) this.slider.leftHandler() };
-    left_obj.dial = left_dial
+    left_dial.handler = function(event) { if (this.slider.leftHandler) this.slider.leftHandler(event); };
+    left_obj.dial = left_dial;
 
     if(make_right) {
-      right_dial = new Dial(right_obj.dial_dom, options);
+      var right_dial = new Dial(right_obj.dial_dom, options);
       right_dial.min = 0;
       right_dial.max = ary.length-1;
       right_dial.text = right_obj.text_dom;
       right_dial.slider = this;
       right_dial.relative_offset = img_width;
       right_dial.index = right_dial.max;
-      right_dial.handler = function() { if (this.slider.rightHandler) this.slider.rightHandler() };
-      right_obj.dial = right_dial
+      right_dial.handler = function(event) { if (this.slider.rightHandler) this.slider.rightHandler(event); };
+      right_obj.dial = right_dial;
 
       left_obj.dial.set_bound = function(index) {
         this.slider.right_obj.dial.min = index;
@@ -149,22 +150,23 @@ Slider.prototype = {
       left_obj.dial.come_up = function() {
         this.slider.left_obj.dial_dom.style.zIndex = 2;
         this.slider.right_obj.dial_dom.style.zIndex = 1;
-      }
+      };
 
       right_obj.dial.set_bound = function(index) {
         this.slider.left_obj.dial.max = index;
-      }
+      };
       right_obj.dial.come_up = function() {
         this.slider.right_obj.dial_dom.style.zIndex = 2;
         this.slider.left_obj.dial_dom.style.zIndex = 1;
-      }
+      };
     }
-    free_dial = new Dial(free_obj.dial_dom, options);
+    var free_dial = new Dial(free_obj.dial_dom, options);
     free_dial.min = 0;
     free_dial.max = ary.length-1;
     free_dial.slider = this;
     free_dial.relative_offset = img_width*2;
     free_dial.index = 0;
+    free_dial.handler = function(event) { if (this.slider.freeHandler) this.slider.freeHandler(event); };
     free_obj.dial = free_dial;
 
 
@@ -182,6 +184,12 @@ Slider.prototype = {
     this.right_obj.text_dom.disabled = true;
     Element.setOpacity(this.right_obj.dial_img, 0.3);
   },
+  enableFree: function(){
+    this.free_obj.dial_dom.show();
+  },
+  disableFree: function(){
+    this.free_obj.dial_dom.hide();
+  },
 
   setLeft: function(val) {
     this.left_obj.text_dom.value = val;
@@ -191,23 +199,31 @@ Slider.prototype = {
     this.right_obj.text_dom.value = val;
     this.moveRightDial();
   },
+  setFree: function(val) {
+    this.free_obj.dial.index = this.valToIndex(val);
+    this.moveFreeDial();
+  },
   getLeft: function() {
     return this.left_obj.text_dom.value;
   },
   getRight: function() {
     return this.right_obj.text_dom.value;
   },
-
-  moveLeftDial: function() {
-    this.moveDial(this.left_obj);
-    if (this.leftHander) this.leftHander();
+  getFree: function() {
+    return this.indexToValAndPos(this.free_obj.dial.index)[0];
   },
-  moveRightDial: function() {
+
+  moveLeftDial: function(event) {
+    this.moveDial(this.left_obj);
+    if (this.leftHandler) this.leftHandler(event);
+  },
+  moveRightDial: function(event) {
     this.moveDial(this.right_obj);
-    if (this.rightHander) this.rightHander();
+    if (this.rightHandler) this.rightHandler(event);
   },
   moveFreeDial: function() {
     this.moveDial(this.free_obj);
+    if (this.freeHandler) this.freeHandler(event);
   },
 
   moveDial: function(obj) {
@@ -235,7 +251,7 @@ Slider.prototype = {
     var index = Math.round(flac*(this.ary.length-1));
     if (index < min) index = min;
     if (index > max) index = max;
-    return index
+    return index;
   },
 
   valToIndex: function(val) {
@@ -255,7 +271,7 @@ Slider.prototype = {
   indexToValAndPos: function(index) {
     var val = this.ary[index];
     var pos = this.left_bound+(this.right_bound-this.left_bound)*index/(this.ary.length-1);
-    return [val, pos]
+    return [val, pos];
   }
 
-}
+};
