@@ -1,84 +1,85 @@
+# -*- coding: cp932 -*-
 require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')
 require 'gphys_gfdnavi'
 require "numru/gfdnavi_data"
 
 
-describe GfdnaviData::Local, "#parse(path)" do
+describe NumRu::GfdnaviData::Local, "#parse(path)" do
   fixtures :nodes
 
-  it "should return GfdnaviData::DirectoryLocal" do
+  it "should return NumRu::GfdnaviData::DirectoryLocal" do
     path = "/samples"
-    gl = GfdnaviData::Local.parse_path(path)
-    gl.should be_instance_of(GfdnaviData::DirectoryLocal)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
+    gl.should be_instance_of(NumRu::GfdnaviData::DirectoryLocal)
   end
 
-  it "should return GfdnaviData::VariableLocal" do
+  it "should return NumRu::GfdnaviData::VariableLocal" do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
-    gl = GfdnaviData::Local.parse_path(path)
-    gl.should be_instance_of(GfdnaviData::VariableLocal)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
+    gl.should be_instance_of(NumRu::GfdnaviData::VariableLocal)
   end
 end
 
-describe GfdnaviData::Local do
+describe NumRu::GfdnaviData::Local do
   fixtures :nodes, :directories, :variables, :images, :users
 
-  it "should return GfdnaviData::ArrayLocal object by #children" do
+  it "should return NumRu::GfdnaviData::ArrayLocal object by #children" do
     path = "/samples/reanalysis"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     gl.should have(1).children
     child = gl.children
-    child.should be_instance_of(GfdnaviData::ArrayLocal)
+    child.should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
     node = child[0]
-    node.should be_instance_of(GfdnaviData::DirectoryLocal)
+    node.should be_instance_of(NumRu::GfdnaviData::DirectoryLocal)
     node.path.should == "/samples/reanalysis/ncep"
 
-    gl = GfdnaviData::Local.parse_path(path,"root")
+    gl = NumRu::GfdnaviData::Local.parse_path(path,"root")
     gl.should have(2).children
   end
 
-  it "should return GfdnaviData::ArrayLocal object by #variables" do
+  it "should return NumRu::GfdnaviData::ArrayLocal object by #variables" do
     path = "/samples/reanalysis/ncep/T.jan.nc"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     gl.should have(1).variables
     vars = gl.variables
-    vars.should be_instance_of(GfdnaviData::ArrayLocal)
+    vars.should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
     var = vars[0]
-    var.should be_instance_of(GfdnaviData::VariableLocal)
+    var.should be_instance_of(NumRu::GfdnaviData::VariableLocal)
     var.path.should == "/samples/reanalysis/ncep/T.jan.nc/T"
   end
 
-  it "should return GfdnaviData::ArrayLocal object by #images" do
+  it "should return NumRu::GfdnaviData::ArrayLocal object by #images" do
     path = "/usr/bob"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     gl.should have(1).images
     img = gl.images[0]
-    img.should be_instance_of(GfdnaviData::ImageLocal)
+    img.should be_instance_of(NumRu::GfdnaviData::ImageLocal)
     img.path.should == "/usr/bob/image.png"
   end
 
-  it "should return GfdnaviData::DirectoryLocal object by #parent" do
+  it "should return NumRu::GfdnaviData::DirectoryLocal object by #parent" do
     path = "/samples/reanalysis"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     parent = gl.parent
-    parent.should be_instance_of(GfdnaviData::DirectoryLocal)
+    parent.should be_instance_of(NumRu::GfdnaviData::DirectoryLocal)
     parent.path.should == "/samples"
   end
 
 end
 
-describe GfdnaviData::Local, "when #analysis method is called" do
+describe NumRu::GfdnaviData::Local, "when #analysis method is called" do
   fixtures :nodes, :variables
   fixtures :functions, :function_arguments, :function_outputs
 
-  it "should return GfdnaviData::ArrayLocal" do
+  it "should return NumRu::GfdnaviData::ArrayLocal" do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     ga = gl.analysis("mean,bob", "lon")
-    ga.should be_instance_of(GfdnaviData::ArrayLocal)
+    ga.should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
     ga.length.should == 1
-    ga[0..0].should  be_instance_of(GfdnaviData::ArrayLocal)
+    ga[0..0].should  be_instance_of(NumRu::GfdnaviData::ArrayLocal)
     gd = ga[0]
-    gd.should be_instance_of(GfdnaviData::VariableLocal)
+    gd.should be_instance_of(NumRu::GfdnaviData::VariableLocal)
     gd.path.should == path+"/analysis(mean,bob;lon)[0]"
     gphys = gd.to_gphys
     gphys.should be_instance_of(NumRu::GPhys)
@@ -87,102 +88,102 @@ describe GfdnaviData::Local, "when #analysis method is called" do
     gphys2.should be_instance_of(NumRu::GPhys)
     gphys2.rank.should == 3
     gd2 = gd.cut("lat"=>0..90)
-    gd2.should be_instance_of(GfdnaviData::VariableLocal)
+    gd2.should be_instance_of(NumRu::GfdnaviData::VariableLocal)
     gd2.to_gphys.coord("lat").val.should == gphys.cut("lat"=>0..90).coord("lat").val
 
     ga3 = gl.analysis("mean", "lon")
-    ga3.should be_instance_of(GfdnaviData::ArrayLocal)
+    ga3.should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
 
-    gl2 = GfdnaviData::Local.parse_path(ga.path)
-    gl2.should be_instance_of(GfdnaviData::ArrayLocal)
+    gl2 = NumRu::GfdnaviData::Local.parse_path(ga.path)
+    gl2.should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
 
-    gl3 = GfdnaviData::Local.parse_path(gd.path)
-    gl3.should be_instance_of(GfdnaviData::VariableLocal)
+    gl3 = NumRu::GfdnaviData::Local.parse_path(gd.path)
+    gl3.should be_instance_of(NumRu::GfdnaviData::VariableLocal)
   end
 
 end
 
-describe GfdnaviData::Local, "when #plot method is called" do
+describe NumRu::GfdnaviData::Local, "when #plot method is called" do
   fixtures :nodes, :variables
-  fixtures :draw_methods
+  fixtures :draw_methods, :draw_method_options, :value_types
 
-  it "should return GfdnaviData::ArrayLocal" do
+  it "should return NumRu::GfdnaviData::ArrayLocal" do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     images = gl.plot("tone,bob")
-    images.should be_instance_of(GfdnaviData::ArrayLocal)
+    images.should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
     images.length.should == 1
     image = images[0]
-    image.should be_instance_of(GfdnaviData::ImageLocal)
-    image.path.should == path+"/plot(tone,bob)[0]"
+    image.should be_instance_of(NumRu::GfdnaviData::ImageLocal)
+    image.path.should == path+"/plot(tone,bob;contour=1,tone=1)[0]"
     png = image.to_png
     png.should be_instance_of(String)
     png.should match(/\A.PNG/)
   end
 end
 
-describe GfdnaviData::ArrayLocal, "when #analysis and #plot method is called" do
+describe NumRu::GfdnaviData::ArrayLocal, "when #analysis and #plot method is called" do
   fixtures :nodes, :variables
   fixtures :functions, :function_arguments, :function_outputs
-  fixtures :draw_methods
+  fixtures :draw_methods, :draw_method_options, :value_types
 
-  it "should return GfdnaviData::ArrayLocal" do
+  it "should return NumRu::GfdnaviData::ArrayLocal" do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     ga = gl.analysis("mean,bob","lon")
 
     images = ga.plot("tone,bob")
-    images.path.should == "/samples/reanalysis/ncep/T.jan.nc/T/analysis(mean,bob;lon)/plot(tone,bob)"
-    GfdnaviData::Local.parse_path(images.path).should be_instance_of(GfdnaviData::ArrayLocal)
+    images.path.should == "/samples/reanalysis/ncep/T.jan.nc/T/analysis(mean,bob;lon)/plot(tone,bob;contour=1,tone=1)"
+    NumRu::GfdnaviData::Local.parse_path(images.path).should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
 
     images = ga[0].plot("tone,bob")
-    images[0].path.should == "/samples/reanalysis/ncep/T.jan.nc/T/analysis(mean,bob;lon)[0]/plot(tone,bob)[0]"
-    GfdnaviData::Local.parse_path(images[0].path).should be_instance_of(GfdnaviData::ImageLocal)
+    images[0].path.should == "/samples/reanalysis/ncep/T.jan.nc/T/analysis(mean,bob;lon)[0]/plot(tone,bob;contour=1,tone=1)[0]"
+    NumRu::GfdnaviData::Local.parse_path(images[0].path).should be_instance_of(NumRu::GfdnaviData::ImageLocal)
   end
 
 end
 
-describe GfdnaviData::ArrayLocal, "when create with GfdnaviData::Array.[]" do
+describe NumRu::GfdnaviData::ArrayLocal, "when create with NumRu::GfdnaviData::Array.[]" do
   fixtures :nodes, :variables
   fixtures :functions, :function_arguments, :function_outputs
-  fixtures :draw_methods
+  fixtures :draw_methods, :draw_method_options, :value_types
 
-  it "should return GfdnaviData::Array" do
-    u = GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/U")
-    v = GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/V")
-    ary = GfdnaviData::Array[u, v]
+  it "should return NumRu::GfdnaviData::Array" do
+    u = NumRu::GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/U")
+    v = NumRu::GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/V")
+    ary = NumRu::GfdnaviData::Array[u, v]
     uv = ary.analysis("addition,bob")[0]
     guv = u.to_gphys + v.to_gphys
     (uv.to_gphys.val - guv.val).abs.max.should == 0.0
   end
 end
 
-describe GfdnaviData::ArrayLocal, "when create path like [path1,path2]" do
-  fixtures :nodes, :variables, :draw_methods
+describe NumRu::GfdnaviData::ArrayLocal, "when create path like [path1,path2]" do
+  fixtures :nodes, :variables, :draw_methods, :draw_method_options, :value_types
 
-  it "should return GfdnaviData::Array and the same as that created with GfdnaviData[]" do
-    u = GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/U")
-    v = GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/V")
-    ary1 = GfdnaviData::Array[u, v]
-    ary2 = GfdnaviData::Local.parse_path("[/samples/reanalysis/ncep/UV.jan.nc/U,/samples/reanalysis/ncep/UV.jan.nc/V]")
+  it "should return NumRu::GfdnaviData::Array and the same as that created with NumRu::GfdnaviData[]" do
+    u = NumRu::GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/U")
+    v = NumRu::GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/UV.jan.nc/V")
+    ary1 = NumRu::GfdnaviData::Array[u, v]
+    ary2 = NumRu::GfdnaviData::Local.parse_path("/[/samples/reanalysis/ncep/UV.jan.nc/U,/samples/reanalysis/ncep/UV.jan.nc/V]")
   
     (ary2[0].to_gphys - ary1[0].to_gphys).val.abs.max.should == 0
     (ary2[1].to_gphys - ary1[1].to_gphys).val.abs.max.should == 0
 
     fig = ary1.plot("vector")
-    fig.should be_instance_of(GfdnaviData::ArrayLocal)
+    fig.should be_instance_of(NumRu::GfdnaviData::ArrayLocal)
     png = fig.to_png
     png.should match(/\A.PNG/)
   end
 end
 
-describe GfdnaviData::ArrayLocal, "when length is one" do
+describe NumRu::GfdnaviData::ArrayLocal, "when length is one" do
   fixtures :nodes, :variables
   fixtures :functions, :function_arguments, :function_outputs
-  fixtures :draw_methods
+  fixtures :draw_methods, :draw_method_options, :value_types
   it "should forward #to_(gphys|png) to self[0]" do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     ga = gl.analysis("mean","lon")
     gphys = ga.to_gphys
     gphys.should be_instance_of(NumRu::GPhys)
@@ -192,54 +193,54 @@ describe GfdnaviData::ArrayLocal, "when length is one" do
   end
 end
 
-describe GfdnaviData::Local do
+describe NumRu::GfdnaviData::Local do
   fixtures :nodes, :variables
   fixtures :functions, :function_arguments, :function_outputs
-  fixtures :draw_methods
+  fixtures :draw_methods, :draw_method_options, :value_types
   it "should give ruby code with #to_rb" do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
 
-    gd = GfdnaviData::Local.parse_path(path)
+    gd = NumRu::GfdnaviData::Local.parse_path(path)
     rb = gd.to_rb
-    gd2 = eval(rb)
+    gd2 = eval(rb, TOPLEVEL_BINDING) # Note: "include NumRu" in the script "rb" may have side effects
 #    gd2.object_id.should_not == gd.object_id
     gd2.path.should == gd.path
 
-    gd = GfdnaviData::Local.parse_path(path).analysis("mean","lon")
+    gd = NumRu::GfdnaviData::Local.parse_path(path).analysis("mean","lon")
     rb = gd.to_rb
-    gd2 = eval(rb)
+    gd2 = eval(rb, TOPLEVEL_BINDING) # Note: "include NumRu" in the script "rb" may have side effects
     gd2.object_id.should_not == gd.object_id
     gd2.path.should == gd.path
 
-    gd = GfdnaviData::Local.parse_path(path).analysis("mean","lon").plot("tone")
+    gd = NumRu::GfdnaviData::Local.parse_path(path).analysis("mean","lon").plot("tone")
     rb = gd.to_rb
-    gd2 = eval(rb)
+    gd2 = eval(rb, TOPLEVEL_BINDING) # Note: "include NumRu" in the script "rb" may have side effects
     gd2.object_id.should_not == gd.object_id
     gd2.path.should == gd.path
 
     path = "/samples/reanalysis/ncep/UV.jan.nc/"
 
-    u = GfdnaviData::Local.parse_path(path+"U").analysis("mean","lon")
-    v = GfdnaviData::Local.parse_path(path+"V").analysis("mean","lon")
-    gd = GfdnaviData::Array[u,v].plot("vector")
+    u = NumRu::GfdnaviData::Local.parse_path(path+"U").analysis("mean","lon")
+    v = NumRu::GfdnaviData::Local.parse_path(path+"V").analysis("mean","lon")
+    gd = NumRu::GfdnaviData::Array[u,v].plot("vector")
     rb = gd.to_rb
-    gd2 = eval(rb)
+    gd2 = eval(rb, TOPLEVEL_BINDING) # Note: "include NumRu" in the script "rb" may have side effects
     gd2.object_id.should_not == gd.object_id
     gd2.path.should == gd.path
   end
 end
 
 
-describe GfdnaviData::Base, "save_as" do
+describe NumRu::GfdnaviData::Base, "save_as" do
   fixtures :nodes, :variables, :images
   fixtures :functions, :function_arguments, :function_outputs
-  fixtures :draw_methods
+  fixtures :draw_methods, :draw_method_options, :value_types
   fixtures :users
   fixtures :diagram_caches
 
   before do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     @v1 = gl.analysis("mean", "lon")[0]
     @d1 = gl.plot("tone")[0]
     @user = User.find(:first, :conditions => ["login=?", "root"])
@@ -276,16 +277,16 @@ describe GfdnaviData::Base, "save_as" do
   end
 end
 
-describe GfdnaviData::Base, "#save" do
+describe NumRu::GfdnaviData::Base, "#save" do
   fixtures :nodes, :variables, :images
   fixtures :functions, :function_arguments, :function_outputs
-  fixtures :draw_methods
+  fixtures :draw_methods, :draw_method_options, :value_types
   fixtures :users
   fixtures :diagram_caches
 
   before do
     path = "/samples/reanalysis/ncep/T.jan.nc/T"
-    gl = GfdnaviData::Local.parse_path(path)
+    gl = NumRu::GfdnaviData::Local.parse_path(path)
     @gphys = gl.analysis("mean", "lon")[0].to_gphys
     @png = gl.plot("tone")[0].to_png
     @user = User.find(:first, :conditions => ["login=?", "root"])
@@ -304,27 +305,27 @@ describe GfdnaviData::Base, "#save" do
   it "gphys should be dave successfully with #save" do
     vname = @gphys.name
     path = File.join("/usr", @user.login, @path_nc, vname)
-    gd = GfdnaviData::VariableLocal.new
+    gd = NumRu::GfdnaviData::VariableLocal.new
     gd.path = path
     gd.name = vname
     gd.owner = @user
     gd.gphys = @gphys
     gd.save
-    gd2 = GfdnaviData::Local.parse_path(path, @user)
-    gd2.should be_instance_of(GfdnaviData::VariableLocal)
+    gd2 = NumRu::GfdnaviData::Local.parse_path(path, @user)
+    gd2.should be_instance_of(NumRu::GfdnaviData::VariableLocal)
   end
 
   # Image
   it "png should be dave successfully with #save" do
     path = File.join("/usr", @user.login, @path_png)
-    gd = GfdnaviData::ImageLocal.new
+    gd = NumRu::GfdnaviData::ImageLocal.new
     gd.path = path
     gd.name = @path_png
     gd.owner = @user
     gd.png = @png
     gd.save
-    gd2 = GfdnaviData::Local.parse_path(path, @user)
-    gd2.should be_instance_of(GfdnaviData::ImageLocal)
+    gd2 = NumRu::GfdnaviData::Local.parse_path(path, @user)
+    gd2.should be_instance_of(NumRu::GfdnaviData::ImageLocal)
   end
 
 end
@@ -334,7 +335,7 @@ end
 # * create knowledge document
 #   * path΃pXŎw, titlecreatorneŵƂhashŎw
 #   * ł to_knlge \bheXg
-describe GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
+describe NumRu::GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
   fixtures :nodes, :variables, :images
   fixtures :knowledges, :knowledge_figures
   fixtures :knowledge_backups, :knowledge_figure_backups
@@ -376,7 +377,7 @@ describe GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
     # * pXA쐬҂̃OCAgqw肵 new B
     #   쐬҂X[p[[ȔꍇACӂ̃pXw肷邱ƂłB
     #   K΃pXŎw肷B
-    new_knowledge = GfdnaviData::KnowledgeLocal.new(@path1, @user1.login)
+    new_knowledge = NumRu::GfdnaviData::KnowledgeLocal.new(@path1, @user1.login)
     # * g
     #   name, other_mode, other_readable, groups_readable,
     #   default_layout, horizontal_figures, 
@@ -402,7 +403,7 @@ describe GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
     k.path.should == @path1
 
     # * to_knlge \bhpāAm̓enbVœ
-    gl = GfdnaviData::Local.parse_path(@path1)
+    gl = NumRu::GfdnaviData::Local.parse_path(@path1)
     k_hash = gl.to_knlge
 
     # * swap_figures \bhpĐ}̏ԂւB
@@ -419,7 +420,7 @@ describe GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
     gl.save_as(@path2, @user1.login)
 
     # * 摜̕ۑ
-    gl_k = GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/T.jan.nc/T")
+    gl_k = NumRu::GfdnaviData::Local.parse_path("/samples/reanalysis/ncep/T.jan.nc/T")
     @d1_k = gl_k.plot("tone")[0]
     @d1_k.save_as(@img_path2, @user2)
 
@@ -430,7 +431,7 @@ describe GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
     #   Ƃēnꂽ path  "/usr/[U/knowledge/c" ̌`ɂȂĂȂ
     #   I "/usr/[U/knowledge/" ȉɕۑ
     #   (ƁA"/usr/[U/knowledge/" ̕ȗĂ\Ȃ)
-    new_knowledge = GfdnaviData::KnowledgeLocal.new(@path3, @user2.login, @hash)
+    new_knowledge = NumRu::GfdnaviData::KnowledgeLocal.new(@path3, @user2.login, @hash)
     # * Gfdnaviō쐬摜}Ƃėp
     new_knowledge.insert_figures = {"image"=>@img_path3, "caption"=>"01\nfirst figure."}, {"image"=>@img_path3, "caption"=>"02\nsecond figure!"}, @user2.login
     new_knowledge.category = "test"
@@ -446,7 +447,7 @@ describe GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
     # * ҏWƂ́A܂ parse B
     #   ̌Ag邱ƂŊ̂̂ƓւB
     #   save 邱ƂőSĂDBƃfBXNɔfB
-    knowledge = GfdnaviData.parse(path)
+    knowledge = NumRu::GfdnaviData.parse(path)
     knowledge.title = "Title is overwritten."
     knowledge.textbody = "teisei simasita yo.\n"
     knowledge.insert_figures = {"image"=>@img_path1, "caption"=>"03."}, {"image"=>@img_path1, "caption"=>"04"}, {"image"=>@img_path1, "caption"=>"05"}, @user2.login
@@ -475,7 +476,7 @@ describe GfdnaviData::KnowledgeLocal, "in createing knowledge document" do
 
     # * m폜ɂ delete \bhpB
     #   save ̕Kv͂ȂB
-    knowledge = GfdnaviData.parse(path)
+    knowledge = NumRu::GfdnaviData.parse(path)
     knowledge.delete(@user2.login)
     
     # * relational_images \bhpĊ֌Ŵ摜 node_id ̃Xg擾łB
