@@ -4,7 +4,7 @@ require 'function_controller'
 # Re-raise errors caught by the controller.
 class FunctionController; def rescue_action(e) raise e end; end
 
-class FunctionControllerTest < Test::Unit::TestCase
+class FunctionControllerTest < ActionController::TestCase
   def setup
     @controller = FunctionController.new
     @request    = ActionController::TestRequest.new
