@@ -4,7 +4,7 @@ require 'group_controller'
 # Re-raise errors caught by the controller.
 class GroupController; def rescue_action(e) raise e end; end
 
-class GroupControllerTest < Test::Unit::TestCase
+class GroupControllerTest < ActionController::TestCase
   def setup
     @controller = GroupController.new
     @request    = ActionController::TestRequest.new
