@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class DiagramCacheDatumTest < Test::Unit::TestCase
+class DiagramCacheDatumTest < ActiveSupport::TestCase
   fixtures :diagram_cache_data
 
   # Replace this with your real tests.
