@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class FigureCacheTest < Test::Unit::TestCase
+class FigureCacheTest < ActiveSupport::TestCase
   fixtures :diagram_caches
 
   # Replace this with your real tests.
