@@ -1,7 +1,7 @@
 require File.dirname(__FILE__) + '/../test_helper'
 require File.expand_path(File.dirname(__FILE__) + "/../../lib/narray_gfdnavi")
 
-class DirectoryTest < Test::Unit::TestCase
+class DirectoryTest < ActiveSupport::TestCase
   fixtures  :directories, :nodes, :users, :groups
 
   def setup
