@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class DrawParameterTest < Test::Unit::TestCase
+class DrawParameterTest < ActiveSupport::TestCase
   fixtures :draw_parameters
 
   # Replace this with your real tests.
