@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class FunctionOutputTest < Test::Unit::TestCase
+class FunctionOutputTest < ActiveSupport::TestCase
   fixtures :function_outputs
 
   # Replace this with your real tests.
