@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class FunctionTest < Test::Unit::TestCase
+class FunctionTest < ActiveSupport::TestCase
   fixtures :functions, :function_arguments, :function_outputs, :nodes, :value_types
 
   # Replace this with your real tests.
