@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class KeywordAttributeTest < Test::Unit::TestCase
+class KeywordAttributeTest < ActiveSupport::TestCase
   fixtures :keyword_attributes, :nodes, :directories, :variables
 
   def setup
