@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class KnowledgeTest < Test::Unit::TestCase
+class KnowledgeTest < ActiveSupport::TestCase
   fixtures :nodes, :knowledges
 
   def setup
