@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../test_helper'
 
-class SpatialAndTimeAttributeTest < Test::Unit::TestCase
+class SpatialAndTimeAttributeTest < ActiveSupport::TestCase
   fixtures :spatial_and_time_attributes, :nodes
 
   def setup
