@@ -1,7 +1,7 @@
 require File.dirname(__FILE__) + '/../test_helper'
 require File.expand_path(File.dirname(__FILE__) + "/../../lib/narray_gfdnavi")
 
-class VariableTest < Test::Unit::TestCase
+class VariableTest < ActiveSupport::TestCase
   fixtures :variables, :directories, :nodes, :users, :groups
 
   def setup
